# encoding: utf-8
#
# Copyright 2015 Canonical Ltd.
#
# Written by:
#   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Macros found in pci.h."""

from libpci._native import Macro

# Million and one macros, not all are automatically converted, convert the
# missing ones manually on a case-by-case basis.

#: Constant from pci.h
PCI_VENDOR_ID = Macro("PCI_VENDOR_ID", 0x00)
#: Constant from pci.h
PCI_DEVICE_ID = Macro("PCI_DEVICE_ID", 0x02)
#: Constant from pci.h
PCI_COMMAND = Macro("PCI_COMMAND", 0x04)
#: Constant from pci.h
PCI_COMMAND_IO = Macro("PCI_COMMAND_IO", 0x1)
#: Constant from pci.h
PCI_COMMAND_MEMORY = Macro("PCI_COMMAND_MEMORY", 0x2)
#: Constant from pci.h
PCI_COMMAND_MASTER = Macro("PCI_COMMAND_MASTER", 0x4)
#: Constant from pci.h
PCI_COMMAND_SPECIAL = Macro("PCI_COMMAND_SPECIAL", 0x8)
#: Constant from pci.h
PCI_COMMAND_INVALIDATE = Macro("PCI_COMMAND_INVALIDATE", 0x10)
#: Constant from pci.h
PCI_COMMAND_VGA_PALETTE = Macro("PCI_COMMAND_VGA_PALETTE", 0x20)
#: Constant from pci.h
PCI_COMMAND_PARITY = Macro("PCI_COMMAND_PARITY", 0x40)
#: Constant from pci.h
PCI_COMMAND_WAIT = Macro("PCI_COMMAND_WAIT", 0x80)
#: Constant from pci.h
PCI_COMMAND_SERR = Macro("PCI_COMMAND_SERR", 0x100)
#: Constant from pci.h
PCI_COMMAND_FAST_BACK = Macro("PCI_COMMAND_FAST_BACK", 0x200)
#: Constant from pci.h
PCI_COMMAND_DISABLE_INTx = Macro("PCI_COMMAND_DISABLE_INTx", 0x400)
#: Constant from pci.h
PCI_STATUS = Macro("PCI_STATUS", 0x06)
#: Constant from pci.h
PCI_STATUS_INTx = Macro("PCI_STATUS_INTx", 0x08)
#: Constant from pci.h
PCI_STATUS_CAP_LIST = Macro("PCI_STATUS_CAP_LIST", 0x10)
#: Constant from pci.h
PCI_STATUS_66MHZ = Macro("PCI_STATUS_66MHZ", 0x20)
#: Constant from pci.h
PCI_STATUS_UDF = Macro("PCI_STATUS_UDF", 0x40)
#: Constant from pci.h
PCI_STATUS_FAST_BACK = Macro("PCI_STATUS_FAST_BACK", 0x80)
#: Constant from pci.h
PCI_STATUS_PARITY = Macro("PCI_STATUS_PARITY", 0x100)
#: Constant from pci.h
PCI_STATUS_DEVSEL_MASK = Macro("PCI_STATUS_DEVSEL_MASK", 0x600)
#: Constant from pci.h
PCI_STATUS_DEVSEL_FAST = Macro("PCI_STATUS_DEVSEL_FAST", 0x000)
#: Constant from pci.h
PCI_STATUS_DEVSEL_MEDIUM = Macro("PCI_STATUS_DEVSEL_MEDIUM", 0x200)
#: Constant from pci.h
PCI_STATUS_DEVSEL_SLOW = Macro("PCI_STATUS_DEVSEL_SLOW", 0x400)
#: Constant from pci.h
PCI_STATUS_SIG_TARGET_ABORT = Macro("PCI_STATUS_SIG_TARGET_ABORT", 0x800)
#: Constant from pci.h
PCI_STATUS_REC_TARGET_ABORT = Macro("PCI_STATUS_REC_TARGET_ABORT", 0x1000)
#: Constant from pci.h
PCI_STATUS_REC_MASTER_ABORT = Macro("PCI_STATUS_REC_MASTER_ABORT", 0x2000)
#: Constant from pci.h
PCI_STATUS_SIG_SYSTEM_ERROR = Macro("PCI_STATUS_SIG_SYSTEM_ERROR", 0x4000)
#: Constant from pci.h
PCI_STATUS_DETECTED_PARITY = Macro("PCI_STATUS_DETECTED_PARITY", 0x8000)
#: Constant from pci.h
PCI_CLASS_REVISION = Macro("PCI_CLASS_REVISION", 0x08)
#: Constant from pci.h
PCI_REVISION_ID = Macro("PCI_REVISION_ID", 0x08)
#: Constant from pci.h
PCI_CLASS_PROG = Macro("PCI_CLASS_PROG", 0x09)
#: Constant from pci.h
PCI_CLASS_DEVICE = Macro("PCI_CLASS_DEVICE", 0x0a)
#: Constant from pci.h
PCI_CACHE_LINE_SIZE = Macro("PCI_CACHE_LINE_SIZE", 0x0c)
#: Constant from pci.h
PCI_LATENCY_TIMER = Macro("PCI_LATENCY_TIMER", 0x0d)
#: Constant from pci.h
PCI_HEADER_TYPE = Macro("PCI_HEADER_TYPE", 0x0e)
#: Constant from pci.h
PCI_HEADER_TYPE_NORMAL = Macro("PCI_HEADER_TYPE_NORMAL", 0)
#: Constant from pci.h
PCI_HEADER_TYPE_BRIDGE = Macro("PCI_HEADER_TYPE_BRIDGE", 1)
#: Constant from pci.h
PCI_HEADER_TYPE_CARDBUS = Macro("PCI_HEADER_TYPE_CARDBUS", 2)
#: Constant from pci.h
PCI_BIST = Macro("PCI_BIST", 0x0f)
#: Constant from pci.h
PCI_BIST_CODE_MASK = Macro("PCI_BIST_CODE_MASK", 0x0f)
#: Constant from pci.h
PCI_BIST_START = Macro("PCI_BIST_START", 0x40)
#: Constant from pci.h
PCI_BIST_CAPABLE = Macro("PCI_BIST_CAPABLE", 0x80)
#: Constant from pci.h
PCI_BASE_ADDRESS_0 = Macro("PCI_BASE_ADDRESS_0", 0x10)
#: Constant from pci.h
PCI_BASE_ADDRESS_1 = Macro("PCI_BASE_ADDRESS_1", 0x14)
#: Constant from pci.h
PCI_BASE_ADDRESS_2 = Macro("PCI_BASE_ADDRESS_2", 0x18)
#: Constant from pci.h
PCI_BASE_ADDRESS_3 = Macro("PCI_BASE_ADDRESS_3", 0x1c)
#: Constant from pci.h
PCI_BASE_ADDRESS_4 = Macro("PCI_BASE_ADDRESS_4", 0x20)
#: Constant from pci.h
PCI_BASE_ADDRESS_5 = Macro("PCI_BASE_ADDRESS_5", 0x24)
#: Constant from pci.h
PCI_BASE_ADDRESS_SPACE = Macro("PCI_BASE_ADDRESS_SPACE", 0x01)
#: Constant from pci.h
PCI_BASE_ADDRESS_SPACE_IO = Macro("PCI_BASE_ADDRESS_SPACE_IO", 0x01)
#: Constant from pci.h
PCI_BASE_ADDRESS_SPACE_MEMORY = Macro("PCI_BASE_ADDRESS_SPACE_MEMORY", 0x00)
#: Constant from pci.h
PCI_BASE_ADDRESS_MEM_TYPE_MASK = Macro("PCI_BASE_ADDRESS_MEM_TYPE_MASK", 0x06)
#: Constant from pci.h
PCI_BASE_ADDRESS_MEM_TYPE_32 = Macro("PCI_BASE_ADDRESS_MEM_TYPE_32", 0x00)
#: Constant from pci.h
PCI_BASE_ADDRESS_MEM_TYPE_1M = Macro("PCI_BASE_ADDRESS_MEM_TYPE_1M", 0x02)
#: Constant from pci.h
PCI_BASE_ADDRESS_MEM_TYPE_64 = Macro("PCI_BASE_ADDRESS_MEM_TYPE_64", 0x04)
#: Constant from pci.h
PCI_BASE_ADDRESS_MEM_PREFETCH = Macro("PCI_BASE_ADDRESS_MEM_PREFETCH", 0x08)
# define  PCI_BASE_ADDRESS_MEM_MASK	(~(pciaddr_t)0x0f)
# define  PCI_BASE_ADDRESS_IO_MASK	(~(pciaddr_t)0x03)
#: Constant from pci.h
PCI_CARDBUS_CIS = Macro("PCI_CARDBUS_CIS", 0x28)
#: Constant from pci.h
PCI_SUBSYSTEM_VENDOR_ID = Macro("PCI_SUBSYSTEM_VENDOR_ID", 0x2c)
#: Constant from pci.h
PCI_SUBSYSTEM_ID = Macro("PCI_SUBSYSTEM_ID", 0x2e)
#: Constant from pci.h
PCI_ROM_ADDRESS = Macro("PCI_ROM_ADDRESS", 0x30)
#: Constant from pci.h
PCI_ROM_ADDRESS_ENABLE = Macro("PCI_ROM_ADDRESS_ENABLE", 0x01)
# define PCI_ROM_ADDRESS_MASK	(~(pciaddr_t)0x7ff)
#: Constant from pci.h
PCI_CAPABILITY_LIST = Macro("PCI_CAPABILITY_LIST", 0x34)
#: Constant from pci.h
PCI_INTERRUPT_LINE = Macro("PCI_INTERRUPT_LINE", 0x3c)
#: Constant from pci.h
PCI_INTERRUPT_PIN = Macro("PCI_INTERRUPT_PIN", 0x3d)
#: Constant from pci.h
PCI_MIN_GNT = Macro("PCI_MIN_GNT", 0x3e)
#: Constant from pci.h
PCI_MAX_LAT = Macro("PCI_MAX_LAT", 0x3f)
#: Constant from pci.h
PCI_PRIMARY_BUS = Macro("PCI_PRIMARY_BUS", 0x18)
#: Constant from pci.h
PCI_SECONDARY_BUS = Macro("PCI_SECONDARY_BUS", 0x19)
#: Constant from pci.h
PCI_SUBORDINATE_BUS = Macro("PCI_SUBORDINATE_BUS", 0x1a)
#: Constant from pci.h
PCI_SEC_LATENCY_TIMER = Macro("PCI_SEC_LATENCY_TIMER", 0x1b)
#: Constant from pci.h
PCI_IO_BASE = Macro("PCI_IO_BASE", 0x1c)
#: Constant from pci.h
PCI_IO_LIMIT = Macro("PCI_IO_LIMIT", 0x1d)
#: Constant from pci.h
PCI_IO_RANGE_TYPE_MASK = Macro("PCI_IO_RANGE_TYPE_MASK", 0x0f)
#: Constant from pci.h
PCI_IO_RANGE_TYPE_16 = Macro("PCI_IO_RANGE_TYPE_16", 0x00)
#: Constant from pci.h
PCI_IO_RANGE_TYPE_32 = Macro("PCI_IO_RANGE_TYPE_32", 0x01)
# define  PCI_IO_RANGE_MASK	~0x0f
#: Constant from pci.h
PCI_SEC_STATUS = Macro("PCI_SEC_STATUS", 0x1e)
#: Constant from pci.h
PCI_MEMORY_BASE = Macro("PCI_MEMORY_BASE", 0x20)
#: Constant from pci.h
PCI_MEMORY_LIMIT = Macro("PCI_MEMORY_LIMIT", 0x22)
#: Constant from pci.h
PCI_MEMORY_RANGE_TYPE_MASK = Macro("PCI_MEMORY_RANGE_TYPE_MASK", 0x0f)
# define  PCI_MEMORY_RANGE_MASK	~0x0f
#: Constant from pci.h
PCI_PREF_MEMORY_BASE = Macro("PCI_PREF_MEMORY_BASE", 0x24)
#: Constant from pci.h
PCI_PREF_MEMORY_LIMIT = Macro("PCI_PREF_MEMORY_LIMIT", 0x26)
#: Constant from pci.h
PCI_PREF_RANGE_TYPE_MASK = Macro("PCI_PREF_RANGE_TYPE_MASK", 0x0f)
#: Constant from pci.h
PCI_PREF_RANGE_TYPE_32 = Macro("PCI_PREF_RANGE_TYPE_32", 0x00)
#: Constant from pci.h
PCI_PREF_RANGE_TYPE_64 = Macro("PCI_PREF_RANGE_TYPE_64", 0x01)
# define  PCI_PREF_RANGE_MASK	~0x0f
#: Constant from pci.h
PCI_PREF_BASE_UPPER32 = Macro("PCI_PREF_BASE_UPPER32", 0x28)
#: Constant from pci.h
PCI_PREF_LIMIT_UPPER32 = Macro("PCI_PREF_LIMIT_UPPER32", 0x2c)
#: Constant from pci.h
PCI_IO_BASE_UPPER16 = Macro("PCI_IO_BASE_UPPER16", 0x30)
#: Constant from pci.h
PCI_IO_LIMIT_UPPER16 = Macro("PCI_IO_LIMIT_UPPER16", 0x32)
#: Constant from pci.h
PCI_ROM_ADDRESS1 = Macro("PCI_ROM_ADDRESS1", 0x38)
#: Constant from pci.h
PCI_BRIDGE_CONTROL = Macro("PCI_BRIDGE_CONTROL", 0x3e)
#: Constant from pci.h
PCI_BRIDGE_CTL_PARITY = Macro("PCI_BRIDGE_CTL_PARITY", 0x01)
#: Constant from pci.h
PCI_BRIDGE_CTL_SERR = Macro("PCI_BRIDGE_CTL_SERR", 0x02)
#: Constant from pci.h
PCI_BRIDGE_CTL_NO_ISA = Macro("PCI_BRIDGE_CTL_NO_ISA", 0x04)
#: Constant from pci.h
PCI_BRIDGE_CTL_VGA = Macro("PCI_BRIDGE_CTL_VGA", 0x08)
#: Constant from pci.h
PCI_BRIDGE_CTL_MASTER_ABORT = Macro("PCI_BRIDGE_CTL_MASTER_ABORT", 0x20)
#: Constant from pci.h
PCI_BRIDGE_CTL_BUS_RESET = Macro("PCI_BRIDGE_CTL_BUS_RESET", 0x40)
#: Constant from pci.h
PCI_BRIDGE_CTL_FAST_BACK = Macro("PCI_BRIDGE_CTL_FAST_BACK", 0x80)
#: Constant from pci.h
PCI_BRIDGE_CTL_PRI_DISCARD_TIMER = Macro(
    "PCI_BRIDGE_CTL_PRI_DISCARD_TIMER", 0x100)
#: Constant from pci.h
PCI_BRIDGE_CTL_SEC_DISCARD_TIMER = Macro(
    "PCI_BRIDGE_CTL_SEC_DISCARD_TIMER", 0x200)
#: Constant from pci.h
PCI_BRIDGE_CTL_DISCARD_TIMER_STATUS = Macro(
    "PCI_BRIDGE_CTL_DISCARD_TIMER_STATUS", 0x400)
#: Constant from pci.h
PCI_BRIDGE_CTL_DISCARD_TIMER_SERR_EN = Macro(
    "PCI_BRIDGE_CTL_DISCARD_TIMER_SERR_EN", 0x800)
#: Constant from pci.h
PCI_CB_CAPABILITY_LIST = Macro("PCI_CB_CAPABILITY_LIST", 0x14)
#: Constant from pci.h
PCI_CB_SEC_STATUS = Macro("PCI_CB_SEC_STATUS", 0x16)
#: Constant from pci.h
PCI_CB_PRIMARY_BUS = Macro("PCI_CB_PRIMARY_BUS", 0x18)
#: Constant from pci.h
PCI_CB_CARD_BUS = Macro("PCI_CB_CARD_BUS", 0x19)
#: Constant from pci.h
PCI_CB_SUBORDINATE_BUS = Macro("PCI_CB_SUBORDINATE_BUS", 0x1a)
#: Constant from pci.h
PCI_CB_LATENCY_TIMER = Macro("PCI_CB_LATENCY_TIMER", 0x1b)
#: Constant from pci.h
PCI_CB_MEMORY_BASE_0 = Macro("PCI_CB_MEMORY_BASE_0", 0x1c)
#: Constant from pci.h
PCI_CB_MEMORY_LIMIT_0 = Macro("PCI_CB_MEMORY_LIMIT_0", 0x20)
#: Constant from pci.h
PCI_CB_MEMORY_BASE_1 = Macro("PCI_CB_MEMORY_BASE_1", 0x24)
#: Constant from pci.h
PCI_CB_MEMORY_LIMIT_1 = Macro("PCI_CB_MEMORY_LIMIT_1", 0x28)
#: Constant from pci.h
PCI_CB_IO_BASE_0 = Macro("PCI_CB_IO_BASE_0", 0x2c)
#: Constant from pci.h
PCI_CB_IO_BASE_0_HI = Macro("PCI_CB_IO_BASE_0_HI", 0x2e)
#: Constant from pci.h
PCI_CB_IO_LIMIT_0 = Macro("PCI_CB_IO_LIMIT_0", 0x30)
#: Constant from pci.h
PCI_CB_IO_LIMIT_0_HI = Macro("PCI_CB_IO_LIMIT_0_HI", 0x32)
#: Constant from pci.h
PCI_CB_IO_BASE_1 = Macro("PCI_CB_IO_BASE_1", 0x34)
#: Constant from pci.h
PCI_CB_IO_BASE_1_HI = Macro("PCI_CB_IO_BASE_1_HI", 0x36)
#: Constant from pci.h
PCI_CB_IO_LIMIT_1 = Macro("PCI_CB_IO_LIMIT_1", 0x38)
#: Constant from pci.h
PCI_CB_IO_LIMIT_1_HI = Macro("PCI_CB_IO_LIMIT_1_HI", 0x3a)
# define  PCI_CB_IO_RANGE_MASK	~0x03
#: Constant from pci.h
PCI_CB_BRIDGE_CONTROL = Macro("PCI_CB_BRIDGE_CONTROL", 0x3e)
#: Constant from pci.h
PCI_CB_BRIDGE_CTL_PARITY = Macro("PCI_CB_BRIDGE_CTL_PARITY", 0x01)
#: Constant from pci.h
PCI_CB_BRIDGE_CTL_SERR = Macro("PCI_CB_BRIDGE_CTL_SERR", 0x02)
#: Constant from pci.h
PCI_CB_BRIDGE_CTL_ISA = Macro("PCI_CB_BRIDGE_CTL_ISA", 0x04)
#: Constant from pci.h
PCI_CB_BRIDGE_CTL_VGA = Macro("PCI_CB_BRIDGE_CTL_VGA", 0x08)
#: Constant from pci.h
PCI_CB_BRIDGE_CTL_MASTER_ABORT = Macro("PCI_CB_BRIDGE_CTL_MASTER_ABORT", 0x20)
#: Constant from pci.h
PCI_CB_BRIDGE_CTL_CB_RESET = Macro("PCI_CB_BRIDGE_CTL_CB_RESET", 0x40)
#: Constant from pci.h
PCI_CB_BRIDGE_CTL_16BIT_INT = Macro("PCI_CB_BRIDGE_CTL_16BIT_INT", 0x80)
#: Constant from pci.h
PCI_CB_BRIDGE_CTL_PREFETCH_MEM0 = Macro(
    "PCI_CB_BRIDGE_CTL_PREFETCH_MEM0", 0x100)
#: Constant from pci.h
PCI_CB_BRIDGE_CTL_PREFETCH_MEM1 = Macro(
    "PCI_CB_BRIDGE_CTL_PREFETCH_MEM1", 0x200)
#: Constant from pci.h
PCI_CB_BRIDGE_CTL_POST_WRITES = Macro("PCI_CB_BRIDGE_CTL_POST_WRITES", 0x400)
#: Constant from pci.h
PCI_CB_SUBSYSTEM_VENDOR_ID = Macro("PCI_CB_SUBSYSTEM_VENDOR_ID", 0x40)
#: Constant from pci.h
PCI_CB_SUBSYSTEM_ID = Macro("PCI_CB_SUBSYSTEM_ID", 0x42)
#: Constant from pci.h
PCI_CB_LEGACY_MODE_BASE = Macro("PCI_CB_LEGACY_MODE_BASE", 0x44)
#: Constant from pci.h
PCI_CAP_LIST_ID = Macro("PCI_CAP_LIST_ID", 0)
#: Constant from pci.h
PCI_CAP_ID_PM = Macro("PCI_CAP_ID_PM", 0x01)
#: Constant from pci.h
PCI_CAP_ID_AGP = Macro("PCI_CAP_ID_AGP", 0x02)
#: Constant from pci.h
PCI_CAP_ID_VPD = Macro("PCI_CAP_ID_VPD", 0x03)
#: Constant from pci.h
PCI_CAP_ID_SLOTID = Macro("PCI_CAP_ID_SLOTID", 0x04)
#: Constant from pci.h
PCI_CAP_ID_MSI = Macro("PCI_CAP_ID_MSI", 0x05)
#: Constant from pci.h
PCI_CAP_ID_CHSWP = Macro("PCI_CAP_ID_CHSWP", 0x06)
#: Constant from pci.h
PCI_CAP_ID_PCIX = Macro("PCI_CAP_ID_PCIX", 0x07)
#: Constant from pci.h
PCI_CAP_ID_HT = Macro("PCI_CAP_ID_HT", 0x08)
#: Constant from pci.h
PCI_CAP_ID_VNDR = Macro("PCI_CAP_ID_VNDR", 0x09)
#: Constant from pci.h
PCI_CAP_ID_DBG = Macro("PCI_CAP_ID_DBG", 0x0A)
#: Constant from pci.h
PCI_CAP_ID_CCRC = Macro("PCI_CAP_ID_CCRC", 0x0B)
#: Constant from pci.h
PCI_CAP_ID_HOTPLUG = Macro("PCI_CAP_ID_HOTPLUG", 0x0C)
#: Constant from pci.h
PCI_CAP_ID_SSVID = Macro("PCI_CAP_ID_SSVID", 0x0D)
#: Constant from pci.h
PCI_CAP_ID_AGP3 = Macro("PCI_CAP_ID_AGP3", 0x0E)
#: Constant from pci.h
PCI_CAP_ID_SECURE = Macro("PCI_CAP_ID_SECURE", 0x0F)
#: Constant from pci.h
PCI_CAP_ID_EXP = Macro("PCI_CAP_ID_EXP", 0x10)
#: Constant from pci.h
PCI_CAP_ID_MSIX = Macro("PCI_CAP_ID_MSIX", 0x11)
#: Constant from pci.h
PCI_CAP_ID_SATA = Macro("PCI_CAP_ID_SATA", 0x12)
#: Constant from pci.h
PCI_CAP_ID_AF = Macro("PCI_CAP_ID_AF", 0x13)
#: Constant from pci.h
PCI_CAP_LIST_NEXT = Macro("PCI_CAP_LIST_NEXT", 1)
#: Constant from pci.h
PCI_CAP_FLAGS = Macro("PCI_CAP_FLAGS", 2)
#: Constant from pci.h
PCI_CAP_SIZEOF = Macro("PCI_CAP_SIZEOF", 4)
#: Constant from pci.h
PCI_EXT_CAP_ID_AER = Macro("PCI_EXT_CAP_ID_AER", 0x01)
#: Constant from pci.h
PCI_EXT_CAP_ID_VC = Macro("PCI_EXT_CAP_ID_VC", 0x02)
#: Constant from pci.h
PCI_EXT_CAP_ID_DSN = Macro("PCI_EXT_CAP_ID_DSN", 0x03)
#: Constant from pci.h
PCI_EXT_CAP_ID_PB = Macro("PCI_EXT_CAP_ID_PB", 0x04)
#: Constant from pci.h
PCI_EXT_CAP_ID_RCLINK = Macro("PCI_EXT_CAP_ID_RCLINK", 0x05)
#: Constant from pci.h
PCI_EXT_CAP_ID_RCILINK = Macro("PCI_EXT_CAP_ID_RCILINK", 0x06)
#: Constant from pci.h
PCI_EXT_CAP_ID_RCECOLL = Macro("PCI_EXT_CAP_ID_RCECOLL", 0x07)
#: Constant from pci.h
PCI_EXT_CAP_ID_MFVC = Macro("PCI_EXT_CAP_ID_MFVC", 0x08)
#: Constant from pci.h
PCI_EXT_CAP_ID_VC2 = Macro("PCI_EXT_CAP_ID_VC2", 0x09)
#: Constant from pci.h
PCI_EXT_CAP_ID_RBCB = Macro("PCI_EXT_CAP_ID_RBCB", 0x0a)
#: Constant from pci.h
PCI_EXT_CAP_ID_VNDR = Macro("PCI_EXT_CAP_ID_VNDR", 0x0b)
#: Constant from pci.h
PCI_EXT_CAP_ID_ACS = Macro("PCI_EXT_CAP_ID_ACS", 0x0d)
#: Constant from pci.h
PCI_EXT_CAP_ID_ARI = Macro("PCI_EXT_CAP_ID_ARI", 0x0e)
#: Constant from pci.h
PCI_EXT_CAP_ID_ATS = Macro("PCI_EXT_CAP_ID_ATS", 0x0f)
#: Constant from pci.h
PCI_EXT_CAP_ID_SRIOV = Macro("PCI_EXT_CAP_ID_SRIOV", 0x10)
#: Constant from pci.h
PCI_EXT_CAP_ID_TPH = Macro("PCI_EXT_CAP_ID_TPH", 0x17)
#: Constant from pci.h
PCI_EXT_CAP_ID_LTR = Macro("PCI_EXT_CAP_ID_LTR", 0x18)
#: Constant from pci.h
PCI_EXT_CAP_ID_L1PM = Macro("PCI_EXT_CAP_ID_L1PM", 0x1e)
#: Constant from pci.h
PCI_PM_CAP_VER_MASK = Macro("PCI_PM_CAP_VER_MASK", 0x0007)
#: Constant from pci.h
PCI_PM_CAP_PME_CLOCK = Macro("PCI_PM_CAP_PME_CLOCK", 0x0008)
#: Constant from pci.h
PCI_PM_CAP_DSI = Macro("PCI_PM_CAP_DSI", 0x0020)
#: Constant from pci.h
PCI_PM_CAP_AUX_C_MASK = Macro("PCI_PM_CAP_AUX_C_MASK", 0x01c0)
#: Constant from pci.h
PCI_PM_CAP_D1 = Macro("PCI_PM_CAP_D1", 0x0200)
#: Constant from pci.h
PCI_PM_CAP_D2 = Macro("PCI_PM_CAP_D2", 0x0400)
#: Constant from pci.h
PCI_PM_CAP_PME_D0 = Macro("PCI_PM_CAP_PME_D0", 0x0800)
#: Constant from pci.h
PCI_PM_CAP_PME_D1 = Macro("PCI_PM_CAP_PME_D1", 0x1000)
#: Constant from pci.h
PCI_PM_CAP_PME_D2 = Macro("PCI_PM_CAP_PME_D2", 0x2000)
#: Constant from pci.h
PCI_PM_CAP_PME_D3_HOT = Macro("PCI_PM_CAP_PME_D3_HOT", 0x4000)
#: Constant from pci.h
PCI_PM_CAP_PME_D3_COLD = Macro("PCI_PM_CAP_PME_D3_COLD", 0x8000)
#: Constant from pci.h
PCI_PM_CTRL = Macro("PCI_PM_CTRL", 4)
#: Constant from pci.h
PCI_PM_CTRL_STATE_MASK = Macro("PCI_PM_CTRL_STATE_MASK", 0x0003)
#: Constant from pci.h
PCI_PM_CTRL_NO_SOFT_RST = Macro("PCI_PM_CTRL_NO_SOFT_RST", 0x0008)
#: Constant from pci.h
PCI_PM_CTRL_PME_ENABLE = Macro("PCI_PM_CTRL_PME_ENABLE", 0x0100)
#: Constant from pci.h
PCI_PM_CTRL_DATA_SEL_MASK = Macro("PCI_PM_CTRL_DATA_SEL_MASK", 0x1e00)
#: Constant from pci.h
PCI_PM_CTRL_DATA_SCALE_MASK = Macro("PCI_PM_CTRL_DATA_SCALE_MASK", 0x6000)
#: Constant from pci.h
PCI_PM_CTRL_PME_STATUS = Macro("PCI_PM_CTRL_PME_STATUS", 0x8000)
#: Constant from pci.h
PCI_PM_PPB_EXTENSIONS = Macro("PCI_PM_PPB_EXTENSIONS", 6)
#: Constant from pci.h
PCI_PM_PPB_B2_B3 = Macro("PCI_PM_PPB_B2_B3", 0x40)
#: Constant from pci.h
PCI_PM_BPCC_ENABLE = Macro("PCI_PM_BPCC_ENABLE", 0x80)
#: Constant from pci.h
PCI_PM_DATA_REGISTER = Macro("PCI_PM_DATA_REGISTER", 7)
#: Constant from pci.h
PCI_PM_SIZEOF = Macro("PCI_PM_SIZEOF", 8)
#: Constant from pci.h
PCI_AGP_VERSION = Macro("PCI_AGP_VERSION", 2)
#: Constant from pci.h
PCI_AGP_RFU = Macro("PCI_AGP_RFU", 3)
#: Constant from pci.h
PCI_AGP_STATUS = Macro("PCI_AGP_STATUS", 4)
#: Constant from pci.h
PCI_AGP_STATUS_RQ_MASK = Macro("PCI_AGP_STATUS_RQ_MASK", 0xff000000)
#: Constant from pci.h
PCI_AGP_STATUS_ISOCH = Macro("PCI_AGP_STATUS_ISOCH", 0x10000)
#: Constant from pci.h
PCI_AGP_STATUS_ARQSZ_MASK = Macro("PCI_AGP_STATUS_ARQSZ_MASK", 0xe000)
#: Constant from pci.h
PCI_AGP_STATUS_CAL_MASK = Macro("PCI_AGP_STATUS_CAL_MASK", 0x1c00)
#: Constant from pci.h
PCI_AGP_STATUS_SBA = Macro("PCI_AGP_STATUS_SBA", 0x0200)
#: Constant from pci.h
PCI_AGP_STATUS_ITA_COH = Macro("PCI_AGP_STATUS_ITA_COH", 0x0100)
#: Constant from pci.h
PCI_AGP_STATUS_GART64 = Macro("PCI_AGP_STATUS_GART64", 0x0080)
#: Constant from pci.h
PCI_AGP_STATUS_HTRANS = Macro("PCI_AGP_STATUS_HTRANS", 0x0040)
#: Constant from pci.h
PCI_AGP_STATUS_64BIT = Macro("PCI_AGP_STATUS_64BIT", 0x0020)
#: Constant from pci.h
PCI_AGP_STATUS_FW = Macro("PCI_AGP_STATUS_FW", 0x0010)
#: Constant from pci.h
PCI_AGP_STATUS_AGP3 = Macro("PCI_AGP_STATUS_AGP3", 0x0008)
#: Constant from pci.h
PCI_AGP_STATUS_RATE4 = Macro("PCI_AGP_STATUS_RATE4", 0x0004)
#: Constant from pci.h
PCI_AGP_STATUS_RATE2 = Macro("PCI_AGP_STATUS_RATE2", 0x0002)
#: Constant from pci.h
PCI_AGP_STATUS_RATE1 = Macro("PCI_AGP_STATUS_RATE1", 0x0001)
#: Constant from pci.h
PCI_AGP_COMMAND = Macro("PCI_AGP_COMMAND", 8)
#: Constant from pci.h
PCI_AGP_COMMAND_RQ_MASK = Macro("PCI_AGP_COMMAND_RQ_MASK", 0xff000000)
#: Constant from pci.h
PCI_AGP_COMMAND_ARQSZ_MASK = Macro("PCI_AGP_COMMAND_ARQSZ_MASK", 0xe000)
#: Constant from pci.h
PCI_AGP_COMMAND_CAL_MASK = Macro("PCI_AGP_COMMAND_CAL_MASK", 0x1c00)
#: Constant from pci.h
PCI_AGP_COMMAND_SBA = Macro("PCI_AGP_COMMAND_SBA", 0x0200)
#: Constant from pci.h
PCI_AGP_COMMAND_AGP = Macro("PCI_AGP_COMMAND_AGP", 0x0100)
#: Constant from pci.h
PCI_AGP_COMMAND_GART64 = Macro("PCI_AGP_COMMAND_GART64", 0x0080)
#: Constant from pci.h
PCI_AGP_COMMAND_64BIT = Macro("PCI_AGP_COMMAND_64BIT", 0x0020)
#: Constant from pci.h
PCI_AGP_COMMAND_FW = Macro("PCI_AGP_COMMAND_FW", 0x0010)
#: Constant from pci.h
PCI_AGP_COMMAND_RATE4 = Macro("PCI_AGP_COMMAND_RATE4", 0x0004)
#: Constant from pci.h
PCI_AGP_COMMAND_RATE2 = Macro("PCI_AGP_COMMAND_RATE2", 0x0002)
#: Constant from pci.h
PCI_AGP_COMMAND_RATE1 = Macro("PCI_AGP_COMMAND_RATE1", 0x0001)
#: Constant from pci.h
PCI_AGP_SIZEOF = Macro("PCI_AGP_SIZEOF", 12)
#: Constant from pci.h
PCI_VPD_ADDR = Macro("PCI_VPD_ADDR", 2)
#: Constant from pci.h
PCI_VPD_ADDR_MASK = Macro("PCI_VPD_ADDR_MASK", 0x7fff)
#: Constant from pci.h
PCI_VPD_ADDR_F = Macro("PCI_VPD_ADDR_F", 0x8000)
#: Constant from pci.h
PCI_VPD_DATA = Macro("PCI_VPD_DATA", 4)
#: Constant from pci.h
PCI_SID_ESR = Macro("PCI_SID_ESR", 2)
#: Constant from pci.h
PCI_SID_ESR_NSLOTS = Macro("PCI_SID_ESR_NSLOTS", 0x1f)
#: Constant from pci.h
PCI_SID_ESR_FIC = Macro("PCI_SID_ESR_FIC", 0x20)
#: Constant from pci.h
PCI_SID_CHASSIS_NR = Macro("PCI_SID_CHASSIS_NR", 3)
#: Constant from pci.h
PCI_MSI_FLAGS = Macro("PCI_MSI_FLAGS", 2)
#: Constant from pci.h
PCI_MSI_FLAGS_MASK_BIT = Macro("PCI_MSI_FLAGS_MASK_BIT", 0x100)
#: Constant from pci.h
PCI_MSI_FLAGS_64BIT = Macro("PCI_MSI_FLAGS_64BIT", 0x080)
#: Constant from pci.h
PCI_MSI_FLAGS_QSIZE = Macro("PCI_MSI_FLAGS_QSIZE", 0x070)
#: Constant from pci.h
PCI_MSI_FLAGS_QMASK = Macro("PCI_MSI_FLAGS_QMASK", 0x00e)
#: Constant from pci.h
PCI_MSI_FLAGS_ENABLE = Macro("PCI_MSI_FLAGS_ENABLE", 0x001)
#: Constant from pci.h
PCI_MSI_RFU = Macro("PCI_MSI_RFU", 3)
#: Constant from pci.h
PCI_MSI_ADDRESS_LO = Macro("PCI_MSI_ADDRESS_LO", 4)
#: Constant from pci.h
PCI_MSI_ADDRESS_HI = Macro("PCI_MSI_ADDRESS_HI", 8)
#: Constant from pci.h
PCI_MSI_DATA_32 = Macro("PCI_MSI_DATA_32", 8)
#: Constant from pci.h
PCI_MSI_DATA_64 = Macro("PCI_MSI_DATA_64", 12)
#: Constant from pci.h
PCI_MSI_MASK_BIT_32 = Macro("PCI_MSI_MASK_BIT_32", 12)
#: Constant from pci.h
PCI_MSI_MASK_BIT_64 = Macro("PCI_MSI_MASK_BIT_64", 16)
#: Constant from pci.h
PCI_MSI_PENDING_32 = Macro("PCI_MSI_PENDING_32", 16)
#: Constant from pci.h
PCI_MSI_PENDING_64 = Macro("PCI_MSI_PENDING_64", 20)
#: Constant from pci.h
PCI_PCIX_COMMAND = Macro("PCI_PCIX_COMMAND", 2)
#: Constant from pci.h
PCI_PCIX_COMMAND_DPERE = Macro("PCI_PCIX_COMMAND_DPERE", 0x0001)
#: Constant from pci.h
PCI_PCIX_COMMAND_ERO = Macro("PCI_PCIX_COMMAND_ERO", 0x0002)
#: Constant from pci.h
PCI_PCIX_COMMAND_MAX_MEM_READ_BYTE_COUNT = Macro(
    "PCI_PCIX_COMMAND_MAX_MEM_READ_BYTE_COUNT", 0x000c)
#: Constant from pci.h
PCI_PCIX_COMMAND_MAX_OUTSTANDING_SPLIT_TRANS = Macro(
    "PCI_PCIX_COMMAND_MAX_OUTSTANDING_SPLIT_TRANS", 0x0070)
#: Constant from pci.h
PCI_PCIX_COMMAND_RESERVED = Macro("PCI_PCIX_COMMAND_RESERVED", 0xf80)
#: Constant from pci.h
PCI_PCIX_STATUS = Macro("PCI_PCIX_STATUS", 4)
#: Constant from pci.h
PCI_PCIX_STATUS_FUNCTION = Macro("PCI_PCIX_STATUS_FUNCTION", 0x00000007)
#: Constant from pci.h
PCI_PCIX_STATUS_DEVICE = Macro("PCI_PCIX_STATUS_DEVICE", 0x000000f8)
#: Constant from pci.h
PCI_PCIX_STATUS_BUS = Macro("PCI_PCIX_STATUS_BUS", 0x0000ff00)
#: Constant from pci.h
PCI_PCIX_STATUS_64BIT = Macro("PCI_PCIX_STATUS_64BIT", 0x00010000)
#: Constant from pci.h
PCI_PCIX_STATUS_133MHZ = Macro("PCI_PCIX_STATUS_133MHZ", 0x00020000)
#: Constant from pci.h
PCI_PCIX_STATUS_SC_DISCARDED = Macro(
    "PCI_PCIX_STATUS_SC_DISCARDED", 0x00040000)
#: Constant from pci.h
PCI_PCIX_STATUS_UNEXPECTED_SC = Macro(
    "PCI_PCIX_STATUS_UNEXPECTED_SC", 0x00080000)
#: Constant from pci.h
PCI_PCIX_STATUS_DEVICE_COMPLEXITY = Macro(
    "PCI_PCIX_STATUS_DEVICE_COMPLEXITY", 0x00100000)
#: Constant from pci.h
PCI_PCIX_STATUS_DESIGNED_MAX_MEM_READ_BYTE_COUNT = Macro(
    "PCI_PCIX_STATUS_DESIGNED_MAX_MEM_READ_BYTE_COUNT", 0x00600000)
#: Constant from pci.h
PCI_PCIX_STATUS_DESIGNED_MAX_OUTSTANDING_SPLIT_TRANS = Macro(
    "PCI_PCIX_STATUS_DESIGNED_MAX_OUTSTANDING_SPLIT_TRANS", 0x03800000)
#: Constant from pci.h
PCI_PCIX_STATUS_DESIGNED_MAX_CUMULATIVE_READ_SIZE = Macro(
    "PCI_PCIX_STATUS_DESIGNED_MAX_CUMULATIVE_READ_SIZE", 0x1c000000)
#: Constant from pci.h
PCI_PCIX_STATUS_RCVD_SC_ERR_MESS = Macro(
    "PCI_PCIX_STATUS_RCVD_SC_ERR_MESS", 0x20000000)
#: Constant from pci.h
PCI_PCIX_STATUS_266MHZ = Macro("PCI_PCIX_STATUS_266MHZ", 0x40000000)
#: Constant from pci.h
PCI_PCIX_STATUS_533MHZ = Macro("PCI_PCIX_STATUS_533MHZ", 0x80000000)
#: Constant from pci.h
PCI_PCIX_SIZEOF = Macro("PCI_PCIX_SIZEOF", 4)
#: Constant from pci.h
PCI_PCIX_BRIDGE_SEC_STATUS = Macro("PCI_PCIX_BRIDGE_SEC_STATUS", 2)
#: Constant from pci.h
PCI_PCIX_BRIDGE_SEC_STATUS_64BIT = Macro(
    "PCI_PCIX_BRIDGE_SEC_STATUS_64BIT", 0x0001)
#: Constant from pci.h
PCI_PCIX_BRIDGE_SEC_STATUS_133MHZ = Macro(
    "PCI_PCIX_BRIDGE_SEC_STATUS_133MHZ", 0x0002)
#: Constant from pci.h
PCI_PCIX_BRIDGE_SEC_STATUS_SC_DISCARDED = Macro(
    "PCI_PCIX_BRIDGE_SEC_STATUS_SC_DISCARDED", 0x0004)
#: Constant from pci.h
PCI_PCIX_BRIDGE_SEC_STATUS_UNEXPECTED_SC = Macro(
    "PCI_PCIX_BRIDGE_SEC_STATUS_UNEXPECTED_SC", 0x0008)
#: Constant from pci.h
PCI_PCIX_BRIDGE_SEC_STATUS_SC_OVERRUN = Macro(
    "PCI_PCIX_BRIDGE_SEC_STATUS_SC_OVERRUN", 0x0010)
#: Constant from pci.h
PCI_PCIX_BRIDGE_SEC_STATUS_SPLIT_REQUEST_DELAYED = Macro(
    "PCI_PCIX_BRIDGE_SEC_STATUS_SPLIT_REQUEST_DELAYED", 0x0020)
#: Constant from pci.h
PCI_PCIX_BRIDGE_SEC_STATUS_CLOCK_FREQ = Macro(
    "PCI_PCIX_BRIDGE_SEC_STATUS_CLOCK_FREQ", 0x01c0)
#: Constant from pci.h
PCI_PCIX_BRIDGE_SEC_STATUS_RESERVED = Macro(
    "PCI_PCIX_BRIDGE_SEC_STATUS_RESERVED", 0xfe00)
#: Constant from pci.h
PCI_PCIX_BRIDGE_STATUS = Macro("PCI_PCIX_BRIDGE_STATUS", 4)
#: Constant from pci.h
PCI_PCIX_BRIDGE_STATUS_FUNCTION = Macro(
    "PCI_PCIX_BRIDGE_STATUS_FUNCTION", 0x00000007)
#: Constant from pci.h
PCI_PCIX_BRIDGE_STATUS_DEVICE = Macro(
    "PCI_PCIX_BRIDGE_STATUS_DEVICE", 0x000000f8)
#: Constant from pci.h
PCI_PCIX_BRIDGE_STATUS_BUS = Macro(
    "PCI_PCIX_BRIDGE_STATUS_BUS", 0x0000ff00)
#: Constant from pci.h
PCI_PCIX_BRIDGE_STATUS_64BIT = Macro(
    "PCI_PCIX_BRIDGE_STATUS_64BIT", 0x00010000)
#: Constant from pci.h
PCI_PCIX_BRIDGE_STATUS_133MHZ = Macro(
    "PCI_PCIX_BRIDGE_STATUS_133MHZ", 0x00020000)
#: Constant from pci.h
PCI_PCIX_BRIDGE_STATUS_SC_DISCARDED = Macro(
    "PCI_PCIX_BRIDGE_STATUS_SC_DISCARDED", 0x00040000)
#: Constant from pci.h
PCI_PCIX_BRIDGE_STATUS_UNEXPECTED_SC = Macro(
    "PCI_PCIX_BRIDGE_STATUS_UNEXPECTED_SC", 0x00080000)
#: Constant from pci.h
PCI_PCIX_BRIDGE_STATUS_SC_OVERRUN = Macro(
    "PCI_PCIX_BRIDGE_STATUS_SC_OVERRUN", 0x00100000)
#: Constant from pci.h
PCI_PCIX_BRIDGE_STATUS_SPLIT_REQUEST_DELAYED = Macro(
    "PCI_PCIX_BRIDGE_STATUS_SPLIT_REQUEST_DELAYED", 0x00200000)
#: Constant from pci.h
PCI_PCIX_BRIDGE_STATUS_RESERVED = Macro(
    "PCI_PCIX_BRIDGE_STATUS_RESERVED", 0xffc00000)
#: Constant from pci.h
PCI_PCIX_BRIDGE_UPSTREAM_SPLIT_TRANS_CTRL = Macro(
    "PCI_PCIX_BRIDGE_UPSTREAM_SPLIT_TRANS_CTRL", 8)
#: Constant from pci.h
PCI_PCIX_BRIDGE_DOWNSTREAM_SPLIT_TRANS_CTRL = Macro(
    "PCI_PCIX_BRIDGE_DOWNSTREAM_SPLIT_TRANS_CTRL", 12)
#: Constant from pci.h
PCI_PCIX_BRIDGE_STR_CAPACITY = Macro(
    "PCI_PCIX_BRIDGE_STR_CAPACITY", 0x0000ffff)
#: Constant from pci.h
PCI_PCIX_BRIDGE_STR_COMMITMENT_LIMIT = Macro(
    "PCI_PCIX_BRIDGE_STR_COMMITMENT_LIMIT", 0xffff0000)
#: Constant from pci.h
PCI_PCIX_BRIDGE_SIZEOF = Macro("PCI_PCIX_BRIDGE_SIZEOF", 12)
#: Constant from pci.h
PCI_HT_CMD = Macro("PCI_HT_CMD", 2)
#: Constant from pci.h
PCI_HT_CMD_TYP_HI = Macro("PCI_HT_CMD_TYP_HI", 0xe000)
#: Constant from pci.h
PCI_HT_CMD_TYP_HI_PRI = Macro("PCI_HT_CMD_TYP_HI_PRI", 0x0000)
#: Constant from pci.h
PCI_HT_CMD_TYP_HI_SEC = Macro("PCI_HT_CMD_TYP_HI_SEC", 0x2000)
#: Constant from pci.h
PCI_HT_CMD_TYP = Macro("PCI_HT_CMD_TYP", 0xf800)
#: Constant from pci.h
PCI_HT_CMD_TYP_SW = Macro("PCI_HT_CMD_TYP_SW", 0x4000)
#: Constant from pci.h
PCI_HT_CMD_TYP_IDC = Macro("PCI_HT_CMD_TYP_IDC", 0x8000)
#: Constant from pci.h
PCI_HT_CMD_TYP_RID = Macro("PCI_HT_CMD_TYP_RID", 0x8800)
#: Constant from pci.h
PCI_HT_CMD_TYP_UIDC = Macro("PCI_HT_CMD_TYP_UIDC", 0x9000)
#: Constant from pci.h
PCI_HT_CMD_TYP_ECSA = Macro("PCI_HT_CMD_TYP_ECSA", 0x9800)
#: Constant from pci.h
PCI_HT_CMD_TYP_AM = Macro("PCI_HT_CMD_TYP_AM", 0xa000)
#: Constant from pci.h
PCI_HT_CMD_TYP_MSIM = Macro("PCI_HT_CMD_TYP_MSIM", 0xa800)
#: Constant from pci.h
PCI_HT_CMD_TYP_DR = Macro("PCI_HT_CMD_TYP_DR", 0xb000)
#: Constant from pci.h
PCI_HT_CMD_TYP_VCS = Macro("PCI_HT_CMD_TYP_VCS", 0xb800)
#: Constant from pci.h
PCI_HT_CMD_TYP_RM = Macro("PCI_HT_CMD_TYP_RM", 0xc000)
#: Constant from pci.h
PCI_HT_CMD_TYP_X86 = Macro("PCI_HT_CMD_TYP_X86", 0xc800)
#: Constant from pci.h
PCI_HT_LCTR_CFLE = Macro("PCI_HT_LCTR_CFLE", 0x0002)
#: Constant from pci.h
PCI_HT_LCTR_CST = Macro("PCI_HT_LCTR_CST", 0x0004)
#: Constant from pci.h
PCI_HT_LCTR_CFE = Macro("PCI_HT_LCTR_CFE", 0x0008)
#: Constant from pci.h
PCI_HT_LCTR_LKFAIL = Macro("PCI_HT_LCTR_LKFAIL", 0x0010)
#: Constant from pci.h
PCI_HT_LCTR_INIT = Macro("PCI_HT_LCTR_INIT", 0x0020)
#: Constant from pci.h
PCI_HT_LCTR_EOC = Macro("PCI_HT_LCTR_EOC", 0x0040)
#: Constant from pci.h
PCI_HT_LCTR_TXO = Macro("PCI_HT_LCTR_TXO", 0x0080)
#: Constant from pci.h
PCI_HT_LCTR_CRCERR = Macro("PCI_HT_LCTR_CRCERR", 0x0f00)
#: Constant from pci.h
PCI_HT_LCTR_ISOCEN = Macro("PCI_HT_LCTR_ISOCEN", 0x1000)
#: Constant from pci.h
PCI_HT_LCTR_LSEN = Macro("PCI_HT_LCTR_LSEN", 0x2000)
#: Constant from pci.h
PCI_HT_LCTR_EXTCTL = Macro("PCI_HT_LCTR_EXTCTL", 0x4000)
#: Constant from pci.h
PCI_HT_LCTR_64B = Macro("PCI_HT_LCTR_64B", 0x8000)
#: Constant from pci.h
PCI_HT_LCNF_MLWI = Macro("PCI_HT_LCNF_MLWI", 0x0007)
#: Constant from pci.h
PCI_HT_LCNF_LW_8B = Macro("PCI_HT_LCNF_LW_8B", 0x0)
#: Constant from pci.h
PCI_HT_LCNF_LW_16B = Macro("PCI_HT_LCNF_LW_16B", 0x1)
#: Constant from pci.h
PCI_HT_LCNF_LW_32B = Macro("PCI_HT_LCNF_LW_32B", 0x3)
#: Constant from pci.h
PCI_HT_LCNF_LW_2B = Macro("PCI_HT_LCNF_LW_2B", 0x4)
#: Constant from pci.h
PCI_HT_LCNF_LW_4B = Macro("PCI_HT_LCNF_LW_4B", 0x5)
#: Constant from pci.h
PCI_HT_LCNF_LW_NC = Macro("PCI_HT_LCNF_LW_NC", 0x7)
#: Constant from pci.h
PCI_HT_LCNF_DFI = Macro("PCI_HT_LCNF_DFI", 0x0008)
#: Constant from pci.h
PCI_HT_LCNF_MLWO = Macro("PCI_HT_LCNF_MLWO", 0x0070)
#: Constant from pci.h
PCI_HT_LCNF_DFO = Macro("PCI_HT_LCNF_DFO", 0x0080)
#: Constant from pci.h
PCI_HT_LCNF_LWI = Macro("PCI_HT_LCNF_LWI", 0x0700)
#: Constant from pci.h
PCI_HT_LCNF_DFIE = Macro("PCI_HT_LCNF_DFIE", 0x0800)
#: Constant from pci.h
PCI_HT_LCNF_LWO = Macro("PCI_HT_LCNF_LWO", 0x7000)
#: Constant from pci.h
PCI_HT_LCNF_DFOE = Macro("PCI_HT_LCNF_DFOE", 0x8000)
#: Constant from pci.h
PCI_HT_RID_MIN = Macro("PCI_HT_RID_MIN", 0x1f)
#: Constant from pci.h
PCI_HT_RID_MAJ = Macro("PCI_HT_RID_MAJ", 0xe0)
#: Constant from pci.h
PCI_HT_LFRER_FREQ = Macro("PCI_HT_LFRER_FREQ", 0x0f)
#: Constant from pci.h
PCI_HT_LFRER_200 = Macro("PCI_HT_LFRER_200", 0x00)
#: Constant from pci.h
PCI_HT_LFRER_300 = Macro("PCI_HT_LFRER_300", 0x01)
#: Constant from pci.h
PCI_HT_LFRER_400 = Macro("PCI_HT_LFRER_400", 0x02)
#: Constant from pci.h
PCI_HT_LFRER_500 = Macro("PCI_HT_LFRER_500", 0x03)
#: Constant from pci.h
PCI_HT_LFRER_600 = Macro("PCI_HT_LFRER_600", 0x04)
#: Constant from pci.h
PCI_HT_LFRER_800 = Macro("PCI_HT_LFRER_800", 0x05)
#: Constant from pci.h
PCI_HT_LFRER_1000 = Macro("PCI_HT_LFRER_1000", 0x06)
#: Constant from pci.h
PCI_HT_LFRER_1200 = Macro("PCI_HT_LFRER_1200", 0x07)
#: Constant from pci.h
PCI_HT_LFRER_1400 = Macro("PCI_HT_LFRER_1400", 0x08)
#: Constant from pci.h
PCI_HT_LFRER_1600 = Macro("PCI_HT_LFRER_1600", 0x09)
#: Constant from pci.h
PCI_HT_LFRER_VEND = Macro("PCI_HT_LFRER_VEND", 0x0f)
#: Constant from pci.h
PCI_HT_LFRER_ERR = Macro("PCI_HT_LFRER_ERR", 0xf0)
#: Constant from pci.h
PCI_HT_LFRER_PROT = Macro("PCI_HT_LFRER_PROT", 0x10)
#: Constant from pci.h
PCI_HT_LFRER_OV = Macro("PCI_HT_LFRER_OV", 0x20)
#: Constant from pci.h
PCI_HT_LFRER_EOC = Macro("PCI_HT_LFRER_EOC", 0x40)
#: Constant from pci.h
PCI_HT_LFRER_CTLT = Macro("PCI_HT_LFRER_CTLT", 0x80)
#: Constant from pci.h
PCI_HT_LFCAP_200 = Macro("PCI_HT_LFCAP_200", 0x0001)
#: Constant from pci.h
PCI_HT_LFCAP_300 = Macro("PCI_HT_LFCAP_300", 0x0002)
#: Constant from pci.h
PCI_HT_LFCAP_400 = Macro("PCI_HT_LFCAP_400", 0x0004)
#: Constant from pci.h
PCI_HT_LFCAP_500 = Macro("PCI_HT_LFCAP_500", 0x0008)
#: Constant from pci.h
PCI_HT_LFCAP_600 = Macro("PCI_HT_LFCAP_600", 0x0010)
#: Constant from pci.h
PCI_HT_LFCAP_800 = Macro("PCI_HT_LFCAP_800", 0x0020)
#: Constant from pci.h
PCI_HT_LFCAP_1000 = Macro("PCI_HT_LFCAP_1000", 0x0040)
#: Constant from pci.h
PCI_HT_LFCAP_1200 = Macro("PCI_HT_LFCAP_1200", 0x0080)
#: Constant from pci.h
PCI_HT_LFCAP_1400 = Macro("PCI_HT_LFCAP_1400", 0x0100)
#: Constant from pci.h
PCI_HT_LFCAP_1600 = Macro("PCI_HT_LFCAP_1600", 0x0200)
#: Constant from pci.h
PCI_HT_LFCAP_VEND = Macro("PCI_HT_LFCAP_VEND", 0x8000)
#: Constant from pci.h
PCI_HT_FTR_ISOCFC = Macro("PCI_HT_FTR_ISOCFC", 0x0001)
#: Constant from pci.h
PCI_HT_FTR_LDTSTOP = Macro("PCI_HT_FTR_LDTSTOP", 0x0002)
#: Constant from pci.h
PCI_HT_FTR_CRCTM = Macro("PCI_HT_FTR_CRCTM", 0x0004)
#: Constant from pci.h
PCI_HT_FTR_ECTLT = Macro("PCI_HT_FTR_ECTLT", 0x0008)
#: Constant from pci.h
PCI_HT_FTR_64BA = Macro("PCI_HT_FTR_64BA", 0x0010)
#: Constant from pci.h
PCI_HT_FTR_UIDRD = Macro("PCI_HT_FTR_UIDRD", 0x0020)
#: Constant from pci.h
PCI_HT_EH_PFLE = Macro("PCI_HT_EH_PFLE", 0x0001)
#: Constant from pci.h
PCI_HT_EH_OFLE = Macro("PCI_HT_EH_OFLE", 0x0002)
#: Constant from pci.h
PCI_HT_EH_PFE = Macro("PCI_HT_EH_PFE", 0x0004)
#: Constant from pci.h
PCI_HT_EH_OFE = Macro("PCI_HT_EH_OFE", 0x0008)
#: Constant from pci.h
PCI_HT_EH_EOCFE = Macro("PCI_HT_EH_EOCFE", 0x0010)
#: Constant from pci.h
PCI_HT_EH_RFE = Macro("PCI_HT_EH_RFE", 0x0020)
#: Constant from pci.h
PCI_HT_EH_CRCFE = Macro("PCI_HT_EH_CRCFE", 0x0040)
#: Constant from pci.h
PCI_HT_EH_SERRFE = Macro("PCI_HT_EH_SERRFE", 0x0080)
#: Constant from pci.h
PCI_HT_EH_CF = Macro("PCI_HT_EH_CF", 0x0100)
#: Constant from pci.h
PCI_HT_EH_RE = Macro("PCI_HT_EH_RE", 0x0200)
#: Constant from pci.h
PCI_HT_EH_PNFE = Macro("PCI_HT_EH_PNFE", 0x0400)
#: Constant from pci.h
PCI_HT_EH_ONFE = Macro("PCI_HT_EH_ONFE", 0x0800)
#: Constant from pci.h
PCI_HT_EH_EOCNFE = Macro("PCI_HT_EH_EOCNFE", 0x1000)
#: Constant from pci.h
PCI_HT_EH_RNFE = Macro("PCI_HT_EH_RNFE", 0x2000)
#: Constant from pci.h
PCI_HT_EH_CRCNFE = Macro("PCI_HT_EH_CRCNFE", 0x4000)
#: Constant from pci.h
PCI_HT_EH_SERRNFE = Macro("PCI_HT_EH_SERRNFE", 0x8000)
#: Constant from pci.h
PCI_HT_PRI_CMD = Macro("PCI_HT_PRI_CMD", 2)
#: Constant from pci.h
PCI_HT_PRI_CMD_BUID = Macro("PCI_HT_PRI_CMD_BUID", 0x001f)
#: Constant from pci.h
PCI_HT_PRI_CMD_UC = Macro("PCI_HT_PRI_CMD_UC", 0x03e0)
#: Constant from pci.h
PCI_HT_PRI_CMD_MH = Macro("PCI_HT_PRI_CMD_MH", 0x0400)
#: Constant from pci.h
PCI_HT_PRI_CMD_DD = Macro("PCI_HT_PRI_CMD_DD", 0x0800)
#: Constant from pci.h
PCI_HT_PRI_CMD_DUL = Macro("PCI_HT_PRI_CMD_DUL", 0x1000)
#: Constant from pci.h
PCI_HT_PRI_LCTR0 = Macro("PCI_HT_PRI_LCTR0", 4)
#: Constant from pci.h
PCI_HT_PRI_LCNF0 = Macro("PCI_HT_PRI_LCNF0", 6)
#: Constant from pci.h
PCI_HT_PRI_LCTR1 = Macro("PCI_HT_PRI_LCTR1", 8)
#: Constant from pci.h
PCI_HT_PRI_LCNF1 = Macro("PCI_HT_PRI_LCNF1", 10)
#: Constant from pci.h
PCI_HT_PRI_RID = Macro("PCI_HT_PRI_RID", 12)
#: Constant from pci.h
PCI_HT_PRI_LFRER0 = Macro("PCI_HT_PRI_LFRER0", 13)
#: Constant from pci.h
PCI_HT_PRI_LFCAP0 = Macro("PCI_HT_PRI_LFCAP0", 14)
#: Constant from pci.h
PCI_HT_PRI_FTR = Macro("PCI_HT_PRI_FTR", 16)
#: Constant from pci.h
PCI_HT_PRI_LFRER1 = Macro("PCI_HT_PRI_LFRER1", 17)
#: Constant from pci.h
PCI_HT_PRI_LFCAP1 = Macro("PCI_HT_PRI_LFCAP1", 18)
#: Constant from pci.h
PCI_HT_PRI_ES = Macro("PCI_HT_PRI_ES", 20)
#: Constant from pci.h
PCI_HT_PRI_EH = Macro("PCI_HT_PRI_EH", 22)
#: Constant from pci.h
PCI_HT_PRI_MBU = Macro("PCI_HT_PRI_MBU", 24)
#: Constant from pci.h
PCI_HT_PRI_MLU = Macro("PCI_HT_PRI_MLU", 25)
#: Constant from pci.h
PCI_HT_PRI_BN = Macro("PCI_HT_PRI_BN", 26)
#: Constant from pci.h
PCI_HT_PRI_SIZEOF = Macro("PCI_HT_PRI_SIZEOF", 28)
#: Constant from pci.h
PCI_HT_SEC_CMD = Macro("PCI_HT_SEC_CMD", 2)
#: Constant from pci.h
PCI_HT_SEC_CMD_WR = Macro("PCI_HT_SEC_CMD_WR", 0x0001)
#: Constant from pci.h
PCI_HT_SEC_CMD_DE = Macro("PCI_HT_SEC_CMD_DE", 0x0002)
#: Constant from pci.h
PCI_HT_SEC_CMD_DN = Macro("PCI_HT_SEC_CMD_DN", 0x0076)
#: Constant from pci.h
PCI_HT_SEC_CMD_CS = Macro("PCI_HT_SEC_CMD_CS", 0x0080)
#: Constant from pci.h
PCI_HT_SEC_CMD_HH = Macro("PCI_HT_SEC_CMD_HH", 0x0100)
#: Constant from pci.h
PCI_HT_SEC_CMD_AS = Macro("PCI_HT_SEC_CMD_AS", 0x0400)
#: Constant from pci.h
PCI_HT_SEC_CMD_HIECE = Macro("PCI_HT_SEC_CMD_HIECE", 0x0800)
#: Constant from pci.h
PCI_HT_SEC_CMD_DUL = Macro("PCI_HT_SEC_CMD_DUL", 0x1000)
#: Constant from pci.h
PCI_HT_SEC_LCTR = Macro("PCI_HT_SEC_LCTR", 4)
#: Constant from pci.h
PCI_HT_SEC_LCNF = Macro("PCI_HT_SEC_LCNF", 6)
#: Constant from pci.h
PCI_HT_SEC_RID = Macro("PCI_HT_SEC_RID", 8)
#: Constant from pci.h
PCI_HT_SEC_LFRER = Macro("PCI_HT_SEC_LFRER", 9)
#: Constant from pci.h
PCI_HT_SEC_LFCAP = Macro("PCI_HT_SEC_LFCAP", 10)
#: Constant from pci.h
PCI_HT_SEC_FTR = Macro("PCI_HT_SEC_FTR", 12)
#: Constant from pci.h
PCI_HT_SEC_FTR_EXTRS = Macro("PCI_HT_SEC_FTR_EXTRS", 0x0100)
#: Constant from pci.h
PCI_HT_SEC_FTR_UCNFE = Macro("PCI_HT_SEC_FTR_UCNFE", 0x0200)
#: Constant from pci.h
PCI_HT_SEC_ES = Macro("PCI_HT_SEC_ES", 16)
#: Constant from pci.h
PCI_HT_SEC_EH = Macro("PCI_HT_SEC_EH", 18)
#: Constant from pci.h
PCI_HT_SEC_MBU = Macro("PCI_HT_SEC_MBU", 20)
#: Constant from pci.h
PCI_HT_SEC_MLU = Macro("PCI_HT_SEC_MLU", 21)
#: Constant from pci.h
PCI_HT_SEC_SIZEOF = Macro("PCI_HT_SEC_SIZEOF", 24)
#: Constant from pci.h
PCI_HT_SW_CMD = Macro("PCI_HT_SW_CMD", 2)
#: Constant from pci.h
PCI_HT_SW_CMD_VIBERR = Macro("PCI_HT_SW_CMD_VIBERR", 0x0080)
#: Constant from pci.h
PCI_HT_SW_CMD_VIBFL = Macro("PCI_HT_SW_CMD_VIBFL", 0x0100)
#: Constant from pci.h
PCI_HT_SW_CMD_VIBFT = Macro("PCI_HT_SW_CMD_VIBFT", 0x0200)
#: Constant from pci.h
PCI_HT_SW_CMD_VIBNFT = Macro("PCI_HT_SW_CMD_VIBNFT", 0x0400)
#: Constant from pci.h
PCI_HT_SW_PMASK = Macro("PCI_HT_SW_PMASK", 4)
#: Constant from pci.h
PCI_HT_SW_SWINF = Macro("PCI_HT_SW_SWINF", 8)
#: Constant from pci.h
PCI_HT_SW_SWINF_DP = Macro("PCI_HT_SW_SWINF_DP", 0x0000001f)
#: Constant from pci.h
PCI_HT_SW_SWINF_EN = Macro("PCI_HT_SW_SWINF_EN", 0x00000020)
#: Constant from pci.h
PCI_HT_SW_SWINF_CR = Macro("PCI_HT_SW_SWINF_CR", 0x00000040)
#: Constant from pci.h
PCI_HT_SW_SWINF_PCIDX = Macro("PCI_HT_SW_SWINF_PCIDX", 0x00000f00)
#: Constant from pci.h
PCI_HT_SW_SWINF_BLRIDX = Macro("PCI_HT_SW_SWINF_BLRIDX", 0x0003f000)
#: Constant from pci.h
PCI_HT_SW_SWINF_SBIDX = Macro("PCI_HT_SW_SWINF_SBIDX", 0x00002000)
#: Constant from pci.h
PCI_HT_SW_SWINF_HP = Macro("PCI_HT_SW_SWINF_HP", 0x00040000)
#: Constant from pci.h
PCI_HT_SW_SWINF_HIDE = Macro("PCI_HT_SW_SWINF_HIDE", 0x00080000)
#: Constant from pci.h
PCI_HT_SW_PCD = Macro("PCI_HT_SW_PCD", 12)
#: Constant from pci.h
PCI_HT_SW_BLRD = Macro("PCI_HT_SW_BLRD", 16)
#: Constant from pci.h
PCI_HT_SW_SBD = Macro("PCI_HT_SW_SBD", 20)
#: Constant from pci.h
PCI_HT_SW_SIZEOF = Macro("PCI_HT_SW_SIZEOF", 24)
#: Constant from pci.h
PCI_HT_SW_PC_PCR = Macro("PCI_HT_SW_PC_PCR", 0x0)
#: Constant from pci.h
PCI_HT_SW_PC_NPCR = Macro("PCI_HT_SW_PC_NPCR", 0x1)
#: Constant from pci.h
PCI_HT_SW_PC_RCR = Macro("PCI_HT_SW_PC_RCR", 0x2)
#: Constant from pci.h
PCI_HT_SW_PC_PDWR = Macro("PCI_HT_SW_PC_PDWR", 0x3)
#: Constant from pci.h
PCI_HT_SW_PC_NPDWR = Macro("PCI_HT_SW_PC_NPDWR", 0x4)
#: Constant from pci.h
PCI_HT_SW_PC_RDWR = Macro("PCI_HT_SW_PC_RDWR", 0x5)
#: Constant from pci.h
PCI_HT_SW_PC_PCT = Macro("PCI_HT_SW_PC_PCT", 0x6)
#: Constant from pci.h
PCI_HT_SW_PC_NPCT = Macro("PCI_HT_SW_PC_NPCT", 0x7)
#: Constant from pci.h
PCI_HT_SW_PC_RCT = Macro("PCI_HT_SW_PC_RCT", 0x8)
#: Constant from pci.h
PCI_HT_SW_PC_PDWT = Macro("PCI_HT_SW_PC_PDWT", 0x9)
#: Constant from pci.h
PCI_HT_SW_PC_NPDWT = Macro("PCI_HT_SW_PC_NPDWT", 0xa)
#: Constant from pci.h
PCI_HT_SW_PC_RDWT = Macro("PCI_HT_SW_PC_RDWT", 0xb)
#: Constant from pci.h
PCI_HT_SW_BLR_BASE0_LO = Macro("PCI_HT_SW_BLR_BASE0_LO", 0x0)
#: Constant from pci.h
PCI_HT_SW_BLR_BASE0_HI = Macro("PCI_HT_SW_BLR_BASE0_HI", 0x1)
#: Constant from pci.h
PCI_HT_SW_BLR_LIM0_LO = Macro("PCI_HT_SW_BLR_LIM0_LO", 0x2)
#: Constant from pci.h
PCI_HT_SW_BLR_LIM0_HI = Macro("PCI_HT_SW_BLR_LIM0_HI", 0x3)
#: Constant from pci.h
PCI_HT_SW_SB_LO = Macro("PCI_HT_SW_SB_LO", 0x0)
#: Constant from pci.h
PCI_HT_SW_S0_HI = Macro("PCI_HT_SW_S0_HI", 0x1)
#: Constant from pci.h
PCI_HT_IDC_IDX = Macro("PCI_HT_IDC_IDX", 2)
#: Constant from pci.h
PCI_HT_IDC_DATA = Macro("PCI_HT_IDC_DATA", 4)
#: Constant from pci.h
PCI_HT_IDC_SIZEOF = Macro("PCI_HT_IDC_SIZEOF", 8)
#: Constant from pci.h
PCI_HT_IDC_IDX_LINT = Macro("PCI_HT_IDC_IDX_LINT", 0x01)
#: Constant from pci.h
PCI_HT_IDC_LINT = Macro("PCI_HT_IDC_LINT", 0x00ff0000)
#: Constant from pci.h
PCI_HT_IDC_IDX_IDR = Macro("PCI_HT_IDC_IDX_IDR", 0x10)
#: Constant from pci.h
PCI_HT_IDC_IDR_MASK = Macro("PCI_HT_IDC_IDR_MASK", 0x10000001)
#: Constant from pci.h
PCI_HT_IDC_IDR_POL = Macro("PCI_HT_IDC_IDR_POL", 0x10000002)
#: Constant from pci.h
PCI_HT_IDC_IDR_II_2 = Macro("PCI_HT_IDC_IDR_II_2", 0x1000001c)
#: Constant from pci.h
PCI_HT_IDC_IDR_II_5 = Macro("PCI_HT_IDC_IDR_II_5", 0x10000020)
#: Constant from pci.h
PCI_HT_IDC_IDR_II_6 = Macro("PCI_HT_IDC_IDR_II_6", 0x00ffffc0)
#: Constant from pci.h
PCI_HT_IDC_IDR_II_24 = Macro("PCI_HT_IDC_IDR_II_24", 0xff000000)
#: Constant from pci.h
PCI_HT_IDC_IDR_II_32 = Macro("PCI_HT_IDC_IDR_II_32", 0x00ffffff)
#: Constant from pci.h
PCI_HT_IDC_IDR_PASSPW = Macro("PCI_HT_IDC_IDR_PASSPW", 0x40000000)
#: Constant from pci.h
PCI_HT_IDC_IDR_WEOI = Macro("PCI_HT_IDC_IDR_WEOI", 0x80000000)
#: Constant from pci.h
PCI_HT_RID_RID = Macro("PCI_HT_RID_RID", 2)
#: Constant from pci.h
PCI_HT_RID_SIZEOF = Macro("PCI_HT_RID_SIZEOF", 4)
#: Constant from pci.h
PCI_HT_UIDC_CS = Macro("PCI_HT_UIDC_CS", 4)
#: Constant from pci.h
PCI_HT_UIDC_CE = Macro("PCI_HT_UIDC_CE", 8)
#: Constant from pci.h
PCI_HT_UIDC_SIZEOF = Macro("PCI_HT_UIDC_SIZEOF", 12)
#: Constant from pci.h
PCI_HT_ECSA_ADDR = Macro("PCI_HT_ECSA_ADDR", 4)
#: Constant from pci.h
PCI_HT_ECSA_ADDR_REG = Macro("PCI_HT_ECSA_ADDR_REG", 0x00000ffc)
#: Constant from pci.h
PCI_HT_ECSA_ADDR_FUN = Macro("PCI_HT_ECSA_ADDR_FUN", 0x00007000)
#: Constant from pci.h
PCI_HT_ECSA_ADDR_DEV = Macro("PCI_HT_ECSA_ADDR_DEV", 0x000f1000)
#: Constant from pci.h
PCI_HT_ECSA_ADDR_BUS = Macro("PCI_HT_ECSA_ADDR_BUS", 0x0ff00000)
#: Constant from pci.h
PCI_HT_ECSA_ADDR_TYPE = Macro("PCI_HT_ECSA_ADDR_TYPE", 0x10000000)
#: Constant from pci.h
PCI_HT_ECSA_DATA = Macro("PCI_HT_ECSA_DATA", 8)
#: Constant from pci.h
PCI_HT_ECSA_SIZEOF = Macro("PCI_HT_ECSA_SIZEOF", 12)
#: Constant from pci.h
PCI_HT_AM_CMD = Macro("PCI_HT_AM_CMD", 2)
#: Constant from pci.h
PCI_HT_AM_CMD_NDMA = Macro("PCI_HT_AM_CMD_NDMA", 0x000f)
#: Constant from pci.h
PCI_HT_AM_CMD_IOSIZ = Macro("PCI_HT_AM_CMD_IOSIZ", 0x01f0)
#: Constant from pci.h
PCI_HT_AM_CMD_MT = Macro("PCI_HT_AM_CMD_MT", 0x0600)
#: Constant from pci.h
PCI_HT_AM_CMD_MT_40B = Macro("PCI_HT_AM_CMD_MT_40B", 0x0000)
#: Constant from pci.h
PCI_HT_AM_CMD_MT_64B = Macro("PCI_HT_AM_CMD_MT_64B", 0x0200)
#: Constant from pci.h
PCI_HT_AM_SBW_CTR_COMP = Macro("PCI_HT_AM_SBW_CTR_COMP", 0x1)
#: Constant from pci.h
PCI_HT_AM_SBW_CTR_NCOH = Macro("PCI_HT_AM_SBW_CTR_NCOH", 0x2)
#: Constant from pci.h
PCI_HT_AM_SBW_CTR_ISOC = Macro("PCI_HT_AM_SBW_CTR_ISOC", 0x4)
#: Constant from pci.h
PCI_HT_AM_SBW_CTR_EN = Macro("PCI_HT_AM_SBW_CTR_EN", 0x8)
#: Constant from pci.h
PCI_HT_AM40_SBNPW = Macro("PCI_HT_AM40_SBNPW", 4)
#: Constant from pci.h
PCI_HT_AM40_SBW_BASE = Macro("PCI_HT_AM40_SBW_BASE", 0x000fffff)
#: Constant from pci.h
PCI_HT_AM40_SBW_CTR = Macro("PCI_HT_AM40_SBW_CTR", 0xf0000000)
#: Constant from pci.h
PCI_HT_AM40_SBPW = Macro("PCI_HT_AM40_SBPW", 8)
#: Constant from pci.h
PCI_HT_AM40_DMA_PBASE0 = Macro("PCI_HT_AM40_DMA_PBASE0", 12)
#: Constant from pci.h
PCI_HT_AM40_DMA_CTR0 = Macro("PCI_HT_AM40_DMA_CTR0", 15)
#: Constant from pci.h
PCI_HT_AM40_DMA_CTR_CTR = Macro("PCI_HT_AM40_DMA_CTR_CTR", 0xf0)
#: Constant from pci.h
PCI_HT_AM40_DMA_SLIM0 = Macro("PCI_HT_AM40_DMA_SLIM0", 16)
#: Constant from pci.h
PCI_HT_AM40_DMA_SBASE0 = Macro("PCI_HT_AM40_DMA_SBASE0", 18)
#: Constant from pci.h
PCI_HT_AM40_SIZEOF = Macro("PCI_HT_AM40_SIZEOF", 12)
#: Constant from pci.h
PCI_HT_AM64_IDX = Macro("PCI_HT_AM64_IDX", 4)
#: Constant from pci.h
PCI_HT_AM64_DATA_LO = Macro("PCI_HT_AM64_DATA_LO", 8)
#: Constant from pci.h
PCI_HT_AM64_DATA_HI = Macro("PCI_HT_AM64_DATA_HI", 12)
#: Constant from pci.h
PCI_HT_AM64_SIZEOF = Macro("PCI_HT_AM64_SIZEOF", 16)
#: Constant from pci.h
PCI_HT_AM64_IDX_SBNPW = Macro("PCI_HT_AM64_IDX_SBNPW", 0x00)
#: Constant from pci.h
PCI_HT_AM64_W_BASE_LO = Macro("PCI_HT_AM64_W_BASE_LO", 0xfff00000)
#: Constant from pci.h
PCI_HT_AM64_W_CTR = Macro("PCI_HT_AM64_W_CTR", 0x0000000f)
#: Constant from pci.h
PCI_HT_AM64_IDX_SBPW = Macro("PCI_HT_AM64_IDX_SBPW", 0x01)
#: Constant from pci.h
PCI_HT_AM64_IDX_PBNPW = Macro("PCI_HT_AM64_IDX_PBNPW", 0x02)
#: Constant from pci.h
PCI_HT_AM64_IDX_DMAPB0 = Macro("PCI_HT_AM64_IDX_DMAPB0", 0x04)
#: Constant from pci.h
PCI_HT_AM64_IDX_DMASB0 = Macro("PCI_HT_AM64_IDX_DMASB0", 0x05)
#: Constant from pci.h
PCI_HT_AM64_IDX_DMASL0 = Macro("PCI_HT_AM64_IDX_DMASL0", 0x06)
#: Constant from pci.h
PCI_HT_MSIM_CMD = Macro("PCI_HT_MSIM_CMD", 2)
#: Constant from pci.h
PCI_HT_MSIM_CMD_EN = Macro("PCI_HT_MSIM_CMD_EN", 0x0001)
#: Constant from pci.h
PCI_HT_MSIM_CMD_FIXD = Macro("PCI_HT_MSIM_CMD_FIXD", 0x0002)
#: Constant from pci.h
PCI_HT_MSIM_ADDR_LO = Macro("PCI_HT_MSIM_ADDR_LO", 4)
#: Constant from pci.h
PCI_HT_MSIM_ADDR_HI = Macro("PCI_HT_MSIM_ADDR_HI", 8)
#: Constant from pci.h
PCI_HT_MSIM_SIZEOF = Macro("PCI_HT_MSIM_SIZEOF", 12)
#: Constant from pci.h
PCI_HT_DR_CMD = Macro("PCI_HT_DR_CMD", 2)
#: Constant from pci.h
PCI_HT_DR_CMD_NDRS = Macro("PCI_HT_DR_CMD_NDRS", 0x000f)
#: Constant from pci.h
PCI_HT_DR_CMD_IDX = Macro("PCI_HT_DR_CMD_IDX", 0x01f0)
#: Constant from pci.h
PCI_HT_DR_EN = Macro("PCI_HT_DR_EN", 4)
#: Constant from pci.h
PCI_HT_DR_DATA = Macro("PCI_HT_DR_DATA", 8)
#: Constant from pci.h
PCI_HT_DR_SIZEOF = Macro("PCI_HT_DR_SIZEOF", 12)
#: Constant from pci.h
PCI_HT_DR_IDX_BASE_LO = Macro("PCI_HT_DR_IDX_BASE_LO", 0x00)
#: Constant from pci.h
PCI_HT_DR_OTNRD = Macro("PCI_HT_DR_OTNRD", 0x00000001)
#: Constant from pci.h
PCI_HT_DR_BL_LO = Macro("PCI_HT_DR_BL_LO", 0xffffff00)
#: Constant from pci.h
PCI_HT_DR_IDX_BASE_HI = Macro("PCI_HT_DR_IDX_BASE_HI", 0x01)
#: Constant from pci.h
PCI_HT_DR_IDX_LIMIT_LO = Macro("PCI_HT_DR_IDX_LIMIT_LO", 0x02)
#: Constant from pci.h
PCI_HT_DR_IDX_LIMIT_HI = Macro("PCI_HT_DR_IDX_LIMIT_HI", 0x03)
#: Constant from pci.h
PCI_HT_VCS_SUP = Macro("PCI_HT_VCS_SUP", 4)
#: Constant from pci.h
PCI_HT_VCS_L1EN = Macro("PCI_HT_VCS_L1EN", 5)
#: Constant from pci.h
PCI_HT_VCS_L0EN = Macro("PCI_HT_VCS_L0EN", 6)
#: Constant from pci.h
PCI_HT_VCS_SBD = Macro("PCI_HT_VCS_SBD", 8)
#: Constant from pci.h
PCI_HT_VCS_SINT = Macro("PCI_HT_VCS_SINT", 9)
#: Constant from pci.h
PCI_HT_VCS_SSUP = Macro("PCI_HT_VCS_SSUP", 10)
#: Constant from pci.h
PCI_HT_VCS_SSUP_0 = Macro("PCI_HT_VCS_SSUP_0", 0x00)
#: Constant from pci.h
PCI_HT_VCS_SSUP_3 = Macro("PCI_HT_VCS_SSUP_3", 0x01)
#: Constant from pci.h
PCI_HT_VCS_SSUP_15 = Macro("PCI_HT_VCS_SSUP_15", 0x02)
#: Constant from pci.h
PCI_HT_VCS_NFCBD = Macro("PCI_HT_VCS_NFCBD", 12)
#: Constant from pci.h
PCI_HT_VCS_NFCINT = Macro("PCI_HT_VCS_NFCINT", 13)
#: Constant from pci.h
PCI_HT_VCS_SIZEOF = Macro("PCI_HT_VCS_SIZEOF", 16)
#: Constant from pci.h
PCI_HT_RM_CTR0 = Macro("PCI_HT_RM_CTR0", 4)
#: Constant from pci.h
PCI_HT_RM_CTR_LRETEN = Macro("PCI_HT_RM_CTR_LRETEN", 0x01)
#: Constant from pci.h
PCI_HT_RM_CTR_FSER = Macro("PCI_HT_RM_CTR_FSER", 0x02)
#: Constant from pci.h
PCI_HT_RM_CTR_ROLNEN = Macro("PCI_HT_RM_CTR_ROLNEN", 0x04)
#: Constant from pci.h
PCI_HT_RM_CTR_FSS = Macro("PCI_HT_RM_CTR_FSS", 0x08)
#: Constant from pci.h
PCI_HT_RM_CTR_RETNEN = Macro("PCI_HT_RM_CTR_RETNEN", 0x10)
#: Constant from pci.h
PCI_HT_RM_CTR_RETFEN = Macro("PCI_HT_RM_CTR_RETFEN", 0x20)
#: Constant from pci.h
PCI_HT_RM_CTR_AA = Macro("PCI_HT_RM_CTR_AA", 0xc0)
#: Constant from pci.h
PCI_HT_RM_STS0 = Macro("PCI_HT_RM_STS0", 5)
#: Constant from pci.h
PCI_HT_RM_STS_RETSNT = Macro("PCI_HT_RM_STS_RETSNT", 0x01)
#: Constant from pci.h
PCI_HT_RM_STS_CNTROL = Macro("PCI_HT_RM_STS_CNTROL", 0x02)
#: Constant from pci.h
PCI_HT_RM_STS_SRCV = Macro("PCI_HT_RM_STS_SRCV", 0x04)
#: Constant from pci.h
PCI_HT_RM_CTR1 = Macro("PCI_HT_RM_CTR1", 6)
#: Constant from pci.h
PCI_HT_RM_STS1 = Macro("PCI_HT_RM_STS1", 7)
#: Constant from pci.h
PCI_HT_RM_CNT0 = Macro("PCI_HT_RM_CNT0", 8)
#: Constant from pci.h
PCI_HT_RM_CNT1 = Macro("PCI_HT_RM_CNT1", 10)
#: Constant from pci.h
PCI_HT_RM_SIZEOF = Macro("PCI_HT_RM_SIZEOF", 12)
#: Constant from pci.h
PCI_VNDR_LENGTH = Macro("PCI_VNDR_LENGTH", 2)
#: Constant from pci.h
PCI_EXP_FLAGS = Macro("PCI_EXP_FLAGS", 0x2)
#: Constant from pci.h
PCI_EXP_FLAGS_VERS = Macro("PCI_EXP_FLAGS_VERS", 0x000f)
#: Constant from pci.h
PCI_EXP_FLAGS_TYPE = Macro("PCI_EXP_FLAGS_TYPE", 0x00f0)
#: Constant from pci.h
PCI_EXP_TYPE_ENDPOINT = Macro("PCI_EXP_TYPE_ENDPOINT", 0x0)
#: Constant from pci.h
PCI_EXP_TYPE_LEG_END = Macro("PCI_EXP_TYPE_LEG_END", 0x1)
#: Constant from pci.h
PCI_EXP_TYPE_ROOT_PORT = Macro("PCI_EXP_TYPE_ROOT_PORT", 0x4)
#: Constant from pci.h
PCI_EXP_TYPE_UPSTREAM = Macro("PCI_EXP_TYPE_UPSTREAM", 0x5)
#: Constant from pci.h
PCI_EXP_TYPE_DOWNSTREAM = Macro("PCI_EXP_TYPE_DOWNSTREAM", 0x6)
#: Constant from pci.h
PCI_EXP_TYPE_PCI_BRIDGE = Macro("PCI_EXP_TYPE_PCI_BRIDGE", 0x7)
#: Constant from pci.h
PCI_EXP_TYPE_PCIE_BRIDGE = Macro("PCI_EXP_TYPE_PCIE_BRIDGE", 0x8)
#: Constant from pci.h
PCI_EXP_TYPE_ROOT_INT_EP = Macro("PCI_EXP_TYPE_ROOT_INT_EP", 0x9)
#: Constant from pci.h
PCI_EXP_TYPE_ROOT_EC = Macro("PCI_EXP_TYPE_ROOT_EC", 0xa)
#: Constant from pci.h
PCI_EXP_FLAGS_SLOT = Macro("PCI_EXP_FLAGS_SLOT", 0x0100)
#: Constant from pci.h
PCI_EXP_FLAGS_IRQ = Macro("PCI_EXP_FLAGS_IRQ", 0x3e00)
#: Constant from pci.h
PCI_EXP_DEVCAP = Macro("PCI_EXP_DEVCAP", 0x4)
#: Constant from pci.h
PCI_EXP_DEVCAP_PAYLOAD = Macro("PCI_EXP_DEVCAP_PAYLOAD", 0x07)
#: Constant from pci.h
PCI_EXP_DEVCAP_PHANTOM = Macro("PCI_EXP_DEVCAP_PHANTOM", 0x18)
#: Constant from pci.h
PCI_EXP_DEVCAP_EXT_TAG = Macro("PCI_EXP_DEVCAP_EXT_TAG", 0x20)
#: Constant from pci.h
PCI_EXP_DEVCAP_L0S = Macro("PCI_EXP_DEVCAP_L0S", 0x1c0)
#: Constant from pci.h
PCI_EXP_DEVCAP_L1 = Macro("PCI_EXP_DEVCAP_L1", 0xe00)
#: Constant from pci.h
PCI_EXP_DEVCAP_ATN_BUT = Macro("PCI_EXP_DEVCAP_ATN_BUT", 0x1000)
#: Constant from pci.h
PCI_EXP_DEVCAP_ATN_IND = Macro("PCI_EXP_DEVCAP_ATN_IND", 0x2000)
#: Constant from pci.h
PCI_EXP_DEVCAP_PWR_IND = Macro("PCI_EXP_DEVCAP_PWR_IND", 0x4000)
#: Constant from pci.h
PCI_EXP_DEVCAP_RBE = Macro("PCI_EXP_DEVCAP_RBE", 0x8000)
#: Constant from pci.h
PCI_EXP_DEVCAP_PWR_VAL = Macro("PCI_EXP_DEVCAP_PWR_VAL", 0x3fc0000)
#: Constant from pci.h
PCI_EXP_DEVCAP_PWR_SCL = Macro("PCI_EXP_DEVCAP_PWR_SCL", 0xc000000)
#: Constant from pci.h
PCI_EXP_DEVCAP_FLRESET = Macro("PCI_EXP_DEVCAP_FLRESET", 0x10000000)
#: Constant from pci.h
PCI_EXP_DEVCTL = Macro("PCI_EXP_DEVCTL", 0x8)
#: Constant from pci.h
PCI_EXP_DEVCTL_CERE = Macro("PCI_EXP_DEVCTL_CERE", 0x0001)
#: Constant from pci.h
PCI_EXP_DEVCTL_NFERE = Macro("PCI_EXP_DEVCTL_NFERE", 0x0002)
#: Constant from pci.h
PCI_EXP_DEVCTL_FERE = Macro("PCI_EXP_DEVCTL_FERE", 0x0004)
#: Constant from pci.h
PCI_EXP_DEVCTL_URRE = Macro("PCI_EXP_DEVCTL_URRE", 0x0008)
#: Constant from pci.h
PCI_EXP_DEVCTL_RELAXED = Macro("PCI_EXP_DEVCTL_RELAXED", 0x0010)
#: Constant from pci.h
PCI_EXP_DEVCTL_PAYLOAD = Macro("PCI_EXP_DEVCTL_PAYLOAD", 0x00e0)
#: Constant from pci.h
PCI_EXP_DEVCTL_EXT_TAG = Macro("PCI_EXP_DEVCTL_EXT_TAG", 0x0100)
#: Constant from pci.h
PCI_EXP_DEVCTL_PHANTOM = Macro("PCI_EXP_DEVCTL_PHANTOM", 0x0200)
#: Constant from pci.h
PCI_EXP_DEVCTL_AUX_PME = Macro("PCI_EXP_DEVCTL_AUX_PME", 0x0400)
#: Constant from pci.h
PCI_EXP_DEVCTL_NOSNOOP = Macro("PCI_EXP_DEVCTL_NOSNOOP", 0x0800)
#: Constant from pci.h
PCI_EXP_DEVCTL_READRQ = Macro("PCI_EXP_DEVCTL_READRQ", 0x7000)
#: Constant from pci.h
PCI_EXP_DEVCTL_BCRE = Macro("PCI_EXP_DEVCTL_BCRE", 0x8000)
#: Constant from pci.h
PCI_EXP_DEVCTL_FLRESET = Macro("PCI_EXP_DEVCTL_FLRESET", 0x8000)
#: Constant from pci.h
PCI_EXP_DEVSTA = Macro("PCI_EXP_DEVSTA", 0xa)
#: Constant from pci.h
PCI_EXP_DEVSTA_CED = Macro("PCI_EXP_DEVSTA_CED", 0x01)
#: Constant from pci.h
PCI_EXP_DEVSTA_NFED = Macro("PCI_EXP_DEVSTA_NFED", 0x02)
#: Constant from pci.h
PCI_EXP_DEVSTA_FED = Macro("PCI_EXP_DEVSTA_FED", 0x04)
#: Constant from pci.h
PCI_EXP_DEVSTA_URD = Macro("PCI_EXP_DEVSTA_URD", 0x08)
#: Constant from pci.h
PCI_EXP_DEVSTA_AUXPD = Macro("PCI_EXP_DEVSTA_AUXPD", 0x10)
#: Constant from pci.h
PCI_EXP_DEVSTA_TRPND = Macro("PCI_EXP_DEVSTA_TRPND", 0x20)
#: Constant from pci.h
PCI_EXP_LNKCAP = Macro("PCI_EXP_LNKCAP", 0xc)
#: Constant from pci.h
PCI_EXP_LNKCAP_SPEED = Macro("PCI_EXP_LNKCAP_SPEED", 0x0000f)
#: Constant from pci.h
PCI_EXP_LNKCAP_WIDTH = Macro("PCI_EXP_LNKCAP_WIDTH", 0x003f0)
#: Constant from pci.h
PCI_EXP_LNKCAP_ASPM = Macro("PCI_EXP_LNKCAP_ASPM", 0x00c00)
#: Constant from pci.h
PCI_EXP_LNKCAP_L0S = Macro("PCI_EXP_LNKCAP_L0S", 0x07000)
#: Constant from pci.h
PCI_EXP_LNKCAP_L1 = Macro("PCI_EXP_LNKCAP_L1", 0x38000)
#: Constant from pci.h
PCI_EXP_LNKCAP_CLOCKPM = Macro("PCI_EXP_LNKCAP_CLOCKPM", 0x40000)
#: Constant from pci.h
PCI_EXP_LNKCAP_SURPRISE = Macro("PCI_EXP_LNKCAP_SURPRISE", 0x80000)
#: Constant from pci.h
PCI_EXP_LNKCAP_DLLA = Macro("PCI_EXP_LNKCAP_DLLA", 0x100000)
#: Constant from pci.h
PCI_EXP_LNKCAP_LBNC = Macro("PCI_EXP_LNKCAP_LBNC", 0x200000)
#: Constant from pci.h
PCI_EXP_LNKCAP_PORT = Macro("PCI_EXP_LNKCAP_PORT", 0xff000000)
#: Constant from pci.h
PCI_EXP_LNKCTL = Macro("PCI_EXP_LNKCTL", 0x10)
#: Constant from pci.h
PCI_EXP_LNKCTL_ASPM = Macro("PCI_EXP_LNKCTL_ASPM", 0x0003)
#: Constant from pci.h
PCI_EXP_LNKCTL_RCB = Macro("PCI_EXP_LNKCTL_RCB", 0x0008)
#: Constant from pci.h
PCI_EXP_LNKCTL_DISABLE = Macro("PCI_EXP_LNKCTL_DISABLE", 0x0010)
#: Constant from pci.h
PCI_EXP_LNKCTL_RETRAIN = Macro("PCI_EXP_LNKCTL_RETRAIN", 0x0020)
#: Constant from pci.h
PCI_EXP_LNKCTL_CLOCK = Macro("PCI_EXP_LNKCTL_CLOCK", 0x0040)
#: Constant from pci.h
PCI_EXP_LNKCTL_XSYNCH = Macro("PCI_EXP_LNKCTL_XSYNCH", 0x0080)
#: Constant from pci.h
PCI_EXP_LNKCTL_CLOCKPM = Macro("PCI_EXP_LNKCTL_CLOCKPM", 0x0100)
#: Constant from pci.h
PCI_EXP_LNKCTL_HWAUTWD = Macro("PCI_EXP_LNKCTL_HWAUTWD", 0x0200)
#: Constant from pci.h
PCI_EXP_LNKCTL_BWMIE = Macro("PCI_EXP_LNKCTL_BWMIE", 0x0400)
#: Constant from pci.h
PCI_EXP_LNKCTL_AUTBWIE = Macro("PCI_EXP_LNKCTL_AUTBWIE", 0x0800)
#: Constant from pci.h
PCI_EXP_LNKSTA = Macro("PCI_EXP_LNKSTA", 0x12)
#: Constant from pci.h
PCI_EXP_LNKSTA_SPEED = Macro("PCI_EXP_LNKSTA_SPEED", 0x000f)
#: Constant from pci.h
PCI_EXP_LNKSTA_WIDTH = Macro("PCI_EXP_LNKSTA_WIDTH", 0x03f0)
#: Constant from pci.h
PCI_EXP_LNKSTA_TR_ERR = Macro("PCI_EXP_LNKSTA_TR_ERR", 0x0400)
#: Constant from pci.h
PCI_EXP_LNKSTA_TRAIN = Macro("PCI_EXP_LNKSTA_TRAIN", 0x0800)
#: Constant from pci.h
PCI_EXP_LNKSTA_SL_CLK = Macro("PCI_EXP_LNKSTA_SL_CLK", 0x1000)
#: Constant from pci.h
PCI_EXP_LNKSTA_DL_ACT = Macro("PCI_EXP_LNKSTA_DL_ACT", 0x2000)
#: Constant from pci.h
PCI_EXP_LNKSTA_BWMGMT = Macro("PCI_EXP_LNKSTA_BWMGMT", 0x4000)
#: Constant from pci.h
PCI_EXP_LNKSTA_AUTBW = Macro("PCI_EXP_LNKSTA_AUTBW", 0x8000)
#: Constant from pci.h
PCI_EXP_SLTCAP = Macro("PCI_EXP_SLTCAP", 0x14)
#: Constant from pci.h
PCI_EXP_SLTCAP_ATNB = Macro("PCI_EXP_SLTCAP_ATNB", 0x0001)
#: Constant from pci.h
PCI_EXP_SLTCAP_PWRC = Macro("PCI_EXP_SLTCAP_PWRC", 0x0002)
#: Constant from pci.h
PCI_EXP_SLTCAP_MRL = Macro("PCI_EXP_SLTCAP_MRL", 0x0004)
#: Constant from pci.h
PCI_EXP_SLTCAP_ATNI = Macro("PCI_EXP_SLTCAP_ATNI", 0x0008)
#: Constant from pci.h
PCI_EXP_SLTCAP_PWRI = Macro("PCI_EXP_SLTCAP_PWRI", 0x0010)
#: Constant from pci.h
PCI_EXP_SLTCAP_HPS = Macro("PCI_EXP_SLTCAP_HPS", 0x0020)
#: Constant from pci.h
PCI_EXP_SLTCAP_HPC = Macro("PCI_EXP_SLTCAP_HPC", 0x0040)
#: Constant from pci.h
PCI_EXP_SLTCAP_PWR_VAL = Macro("PCI_EXP_SLTCAP_PWR_VAL", 0x00007f80)
#: Constant from pci.h
PCI_EXP_SLTCAP_PWR_SCL = Macro("PCI_EXP_SLTCAP_PWR_SCL", 0x00018000)
#: Constant from pci.h
PCI_EXP_SLTCAP_INTERLOCK = Macro("PCI_EXP_SLTCAP_INTERLOCK", 0x020000)
#: Constant from pci.h
PCI_EXP_SLTCAP_NOCMDCOMP = Macro("PCI_EXP_SLTCAP_NOCMDCOMP", 0x040000)
#: Constant from pci.h
PCI_EXP_SLTCAP_PSN = Macro("PCI_EXP_SLTCAP_PSN", 0xfff80000)
#: Constant from pci.h
PCI_EXP_SLTCTL = Macro("PCI_EXP_SLTCTL", 0x18)
#: Constant from pci.h
PCI_EXP_SLTCTL_ATNB = Macro("PCI_EXP_SLTCTL_ATNB", 0x0001)
#: Constant from pci.h
PCI_EXP_SLTCTL_PWRF = Macro("PCI_EXP_SLTCTL_PWRF", 0x0002)
#: Constant from pci.h
PCI_EXP_SLTCTL_MRLS = Macro("PCI_EXP_SLTCTL_MRLS", 0x0004)
#: Constant from pci.h
PCI_EXP_SLTCTL_PRSD = Macro("PCI_EXP_SLTCTL_PRSD", 0x0008)
#: Constant from pci.h
PCI_EXP_SLTCTL_CMDC = Macro("PCI_EXP_SLTCTL_CMDC", 0x0010)
#: Constant from pci.h
PCI_EXP_SLTCTL_HPIE = Macro("PCI_EXP_SLTCTL_HPIE", 0x0020)
#: Constant from pci.h
PCI_EXP_SLTCTL_ATNI = Macro("PCI_EXP_SLTCTL_ATNI", 0x00c0)
#: Constant from pci.h
PCI_EXP_SLTCTL_PWRI = Macro("PCI_EXP_SLTCTL_PWRI", 0x0300)
#: Constant from pci.h
PCI_EXP_SLTCTL_PWRC = Macro("PCI_EXP_SLTCTL_PWRC", 0x0400)
#: Constant from pci.h
PCI_EXP_SLTCTL_INTERLOCK = Macro("PCI_EXP_SLTCTL_INTERLOCK", 0x0800)
#: Constant from pci.h
PCI_EXP_SLTCTL_LLCHG = Macro("PCI_EXP_SLTCTL_LLCHG", 0x1000)
#: Constant from pci.h
PCI_EXP_SLTSTA = Macro("PCI_EXP_SLTSTA", 0x1a)
#: Constant from pci.h
PCI_EXP_SLTSTA_ATNB = Macro("PCI_EXP_SLTSTA_ATNB", 0x0001)
#: Constant from pci.h
PCI_EXP_SLTSTA_PWRF = Macro("PCI_EXP_SLTSTA_PWRF", 0x0002)
#: Constant from pci.h
PCI_EXP_SLTSTA_MRLS = Macro("PCI_EXP_SLTSTA_MRLS", 0x0004)
#: Constant from pci.h
PCI_EXP_SLTSTA_PRSD = Macro("PCI_EXP_SLTSTA_PRSD", 0x0008)
#: Constant from pci.h
PCI_EXP_SLTSTA_CMDC = Macro("PCI_EXP_SLTSTA_CMDC", 0x0010)
#: Constant from pci.h
PCI_EXP_SLTSTA_MRL_ST = Macro("PCI_EXP_SLTSTA_MRL_ST", 0x0020)
#: Constant from pci.h
PCI_EXP_SLTSTA_PRES = Macro("PCI_EXP_SLTSTA_PRES", 0x0040)
#: Constant from pci.h
PCI_EXP_SLTSTA_INTERLOCK = Macro("PCI_EXP_SLTSTA_INTERLOCK", 0x0080)
#: Constant from pci.h
PCI_EXP_SLTSTA_LLCHG = Macro("PCI_EXP_SLTSTA_LLCHG", 0x0100)
#: Constant from pci.h
PCI_EXP_RTCTL = Macro("PCI_EXP_RTCTL", 0x1c)
#: Constant from pci.h
PCI_EXP_RTCTL_SECEE = Macro("PCI_EXP_RTCTL_SECEE", 0x0001)
#: Constant from pci.h
PCI_EXP_RTCTL_SENFEE = Macro("PCI_EXP_RTCTL_SENFEE", 0x0002)
#: Constant from pci.h
PCI_EXP_RTCTL_SEFEE = Macro("PCI_EXP_RTCTL_SEFEE", 0x0004)
#: Constant from pci.h
PCI_EXP_RTCTL_PMEIE = Macro("PCI_EXP_RTCTL_PMEIE", 0x0008)
#: Constant from pci.h
PCI_EXP_RTCTL_CRSVIS = Macro("PCI_EXP_RTCTL_CRSVIS", 0x0010)
#: Constant from pci.h
PCI_EXP_RTCAP = Macro("PCI_EXP_RTCAP", 0x1e)
#: Constant from pci.h
PCI_EXP_RTCAP_CRSVIS = Macro("PCI_EXP_RTCAP_CRSVIS", 0x0010)
#: Constant from pci.h
PCI_EXP_RTSTA = Macro("PCI_EXP_RTSTA", 0x20)
#: Constant from pci.h
PCI_EXP_RTSTA_PME_REQID = Macro("PCI_EXP_RTSTA_PME_REQID", 0x0000ffff)
#: Constant from pci.h
PCI_EXP_RTSTA_PME_STATUS = Macro("PCI_EXP_RTSTA_PME_STATUS", 0x00010000)
#: Constant from pci.h
PCI_EXP_RTSTA_PME_PENDING = Macro("PCI_EXP_RTSTA_PME_PENDING", 0x00020000)
#: Constant from pci.h
PCI_EXP_DEVCAP2 = Macro("PCI_EXP_DEVCAP2", 0x24)
#: Constant from pci.h
PCI_EXP_DEVCAP2_LTR = Macro("PCI_EXP_DEVCAP2_LTR", 0x0800)
# define  PCI_EXP_DEVCAP2_OBFF(x)	(((x) >> 18) & 3)
#: Constant from pci.h
PCI_EXP_DEVCTL2 = Macro("PCI_EXP_DEVCTL2", 0x28)
# define  PCI_EXP_DEV2_TIMEOUT_RANGE(x)	((x) & 0xf)
# define  PCI_EXP_DEV2_TIMEOUT_VALUE(x)	((x) & 0xf)
#: Constant from pci.h
PCI_EXP_DEV2_TIMEOUT_DIS = Macro("PCI_EXP_DEV2_TIMEOUT_DIS", 0x0010)
#: Constant from pci.h
PCI_EXP_DEV2_ARI = Macro("PCI_EXP_DEV2_ARI", 0x0020)
#: Constant from pci.h
PCI_EXP_DEV2_LTR = Macro("PCI_EXP_DEV2_LTR", 0x0400)
# define  PCI_EXP_DEV2_OBFF(x)		(((x) >> 13) & 3)
#: Constant from pci.h
PCI_EXP_DEVSTA2 = Macro("PCI_EXP_DEVSTA2", 0x2a)
#: Constant from pci.h
PCI_EXP_LNKCAP2 = Macro("PCI_EXP_LNKCAP2", 0x2c)
#: Constant from pci.h
PCI_EXP_LNKCTL2 = Macro("PCI_EXP_LNKCTL2", 0x30)
# define  PCI_EXP_LNKCTL2_SPEED(x)	((x) & 0xf)
#: Constant from pci.h
PCI_EXP_LNKCTL2_CMPLNC = Macro("PCI_EXP_LNKCTL2_CMPLNC", 0x0010)
#: Constant from pci.h
PCI_EXP_LNKCTL2_SPEED_DIS = Macro("PCI_EXP_LNKCTL2_SPEED_DIS", 0x0020)
# define  PCI_EXP_LNKCTL2_DEEMPHASIS(x)	(((x) >> 6) & 1)
# define  PCI_EXP_LNKCTL2_MARGIN(x)	(((x) >> 7) & 7)
#: Constant from pci.h
PCI_EXP_LNKCTL2_MOD_CMPLNC = Macro("PCI_EXP_LNKCTL2_MOD_CMPLNC", 0x0400)
#: Constant from pci.h
PCI_EXP_LNKCTL2_CMPLNC_SOS = Macro("PCI_EXP_LNKCTL2_CMPLNC_SOS", 0x0800)
# define  PCI_EXP_LNKCTL2_COM_DEEMPHASIS(x) (((x) >> 12) & 0xf)
#: Constant from pci.h
PCI_EXP_LNKSTA2 = Macro("PCI_EXP_LNKSTA2", 0x32)
# define  PCI_EXP_LINKSTA2_DEEMPHASIS(x)	((x) & 1)
#: Constant from pci.h
PCI_EXP_LINKSTA2_EQU_COMP = Macro("PCI_EXP_LINKSTA2_EQU_COMP", 0x02)
#: Constant from pci.h
PCI_EXP_LINKSTA2_EQU_PHASE1 = Macro("PCI_EXP_LINKSTA2_EQU_PHASE1", 0x04)
#: Constant from pci.h
PCI_EXP_LINKSTA2_EQU_PHASE2 = Macro("PCI_EXP_LINKSTA2_EQU_PHASE2", 0x08)
#: Constant from pci.h
PCI_EXP_LINKSTA2_EQU_PHASE3 = Macro("PCI_EXP_LINKSTA2_EQU_PHASE3", 0x10)
#: Constant from pci.h
PCI_EXP_LINKSTA2_EQU_REQ = Macro("PCI_EXP_LINKSTA2_EQU_REQ", 0x20)
#: Constant from pci.h
PCI_EXP_SLTCAP2 = Macro("PCI_EXP_SLTCAP2", 0x34)
#: Constant from pci.h
PCI_EXP_SLTCTL2 = Macro("PCI_EXP_SLTCTL2", 0x38)
#: Constant from pci.h
PCI_EXP_SLTSTA2 = Macro("PCI_EXP_SLTSTA2", 0x3a)
#: Constant from pci.h
PCI_MSIX_ENABLE = Macro("PCI_MSIX_ENABLE", 0x8000)
#: Constant from pci.h
PCI_MSIX_MASK = Macro("PCI_MSIX_MASK", 0x4000)
#: Constant from pci.h
PCI_MSIX_TABSIZE = Macro("PCI_MSIX_TABSIZE", 0x07ff)
#: Constant from pci.h
PCI_MSIX_TABLE = Macro("PCI_MSIX_TABLE", 4)
#: Constant from pci.h
PCI_MSIX_PBA = Macro("PCI_MSIX_PBA", 8)
#: Constant from pci.h
PCI_MSIX_BIR = Macro("PCI_MSIX_BIR", 0x7)
#: Constant from pci.h
PCI_SSVID_VENDOR = Macro("PCI_SSVID_VENDOR", 4)
#: Constant from pci.h
PCI_SSVID_DEVICE = Macro("PCI_SSVID_DEVICE", 6)
#: Constant from pci.h
PCI_AF_CAP = Macro("PCI_AF_CAP", 3)
#: Constant from pci.h
PCI_AF_CAP_TP = Macro("PCI_AF_CAP_TP", 0x01)
#: Constant from pci.h
PCI_AF_CAP_FLR = Macro("PCI_AF_CAP_FLR", 0x02)
#: Constant from pci.h
PCI_AF_CTRL = Macro("PCI_AF_CTRL", 4)
#: Constant from pci.h
PCI_AF_CTRL_FLR = Macro("PCI_AF_CTRL_FLR", 0x01)
#: Constant from pci.h
PCI_AF_STATUS = Macro("PCI_AF_STATUS", 5)
#: Constant from pci.h
PCI_AF_STATUS_TP = Macro("PCI_AF_STATUS_TP", 0x01)
#: Constant from pci.h
PCI_SATA_HBA_BARS = Macro("PCI_SATA_HBA_BARS", 4)
#: Constant from pci.h
PCI_SATA_HBA_REG0 = Macro("PCI_SATA_HBA_REG0", 8)
#: Constant from pci.h
PCI_ERR_UNCOR_STATUS = Macro("PCI_ERR_UNCOR_STATUS", 4)
#: Constant from pci.h
PCI_ERR_UNC_TRAIN = Macro("PCI_ERR_UNC_TRAIN", 0x00000001)
#: Constant from pci.h
PCI_ERR_UNC_DLP = Macro("PCI_ERR_UNC_DLP", 0x00000010)
#: Constant from pci.h
PCI_ERR_UNC_SDES = Macro("PCI_ERR_UNC_SDES", 0x00000020)
#: Constant from pci.h
PCI_ERR_UNC_POISON_TLP = Macro("PCI_ERR_UNC_POISON_TLP", 0x00001000)
#: Constant from pci.h
PCI_ERR_UNC_FCP = Macro("PCI_ERR_UNC_FCP", 0x00002000)
#: Constant from pci.h
PCI_ERR_UNC_COMP_TIME = Macro("PCI_ERR_UNC_COMP_TIME", 0x00004000)
#: Constant from pci.h
PCI_ERR_UNC_COMP_ABORT = Macro("PCI_ERR_UNC_COMP_ABORT", 0x00008000)
#: Constant from pci.h
PCI_ERR_UNC_UNX_COMP = Macro("PCI_ERR_UNC_UNX_COMP", 0x00010000)
#: Constant from pci.h
PCI_ERR_UNC_RX_OVER = Macro("PCI_ERR_UNC_RX_OVER", 0x00020000)
#: Constant from pci.h
PCI_ERR_UNC_MALF_TLP = Macro("PCI_ERR_UNC_MALF_TLP", 0x00040000)
#: Constant from pci.h
PCI_ERR_UNC_ECRC = Macro("PCI_ERR_UNC_ECRC", 0x00080000)
#: Constant from pci.h
PCI_ERR_UNC_UNSUP = Macro("PCI_ERR_UNC_UNSUP", 0x00100000)
#: Constant from pci.h
PCI_ERR_UNC_ACS_VIOL = Macro("PCI_ERR_UNC_ACS_VIOL", 0x00200000)
#: Constant from pci.h
PCI_ERR_UNCOR_MASK = Macro("PCI_ERR_UNCOR_MASK", 8)
#: Constant from pci.h
PCI_ERR_UNCOR_SEVER = Macro("PCI_ERR_UNCOR_SEVER", 12)
#: Constant from pci.h
PCI_ERR_COR_STATUS = Macro("PCI_ERR_COR_STATUS", 16)
#: Constant from pci.h
PCI_ERR_COR_RCVR = Macro("PCI_ERR_COR_RCVR", 0x00000001)
#: Constant from pci.h
PCI_ERR_COR_BAD_TLP = Macro("PCI_ERR_COR_BAD_TLP", 0x00000040)
#: Constant from pci.h
PCI_ERR_COR_BAD_DLLP = Macro("PCI_ERR_COR_BAD_DLLP", 0x00000080)
#: Constant from pci.h
PCI_ERR_COR_REP_ROLL = Macro("PCI_ERR_COR_REP_ROLL", 0x00000100)
#: Constant from pci.h
PCI_ERR_COR_REP_TIMER = Macro("PCI_ERR_COR_REP_TIMER", 0x00001000)
#: Constant from pci.h
PCI_ERR_COR_REP_ANFE = Macro("PCI_ERR_COR_REP_ANFE", 0x00002000)
#: Constant from pci.h
PCI_ERR_COR_MASK = Macro("PCI_ERR_COR_MASK", 20)
#: Constant from pci.h
PCI_ERR_CAP = Macro("PCI_ERR_CAP", 24)
# define  PCI_ERR_CAP_FEP(x)	((x) & 31)
#: Constant from pci.h
PCI_ERR_CAP_ECRC_GENC = Macro("PCI_ERR_CAP_ECRC_GENC", 0x00000020)
#: Constant from pci.h
PCI_ERR_CAP_ECRC_GENE = Macro("PCI_ERR_CAP_ECRC_GENE", 0x00000040)
#: Constant from pci.h
PCI_ERR_CAP_ECRC_CHKC = Macro("PCI_ERR_CAP_ECRC_CHKC", 0x00000080)
#: Constant from pci.h
PCI_ERR_CAP_ECRC_CHKE = Macro("PCI_ERR_CAP_ECRC_CHKE", 0x00000100)
#: Constant from pci.h
PCI_ERR_HEADER_LOG = Macro("PCI_ERR_HEADER_LOG", 28)
#: Constant from pci.h
PCI_ERR_ROOT_COMMAND = Macro("PCI_ERR_ROOT_COMMAND", 44)
#: Constant from pci.h
PCI_ERR_ROOT_STATUS = Macro("PCI_ERR_ROOT_STATUS", 48)
#: Constant from pci.h
PCI_ERR_ROOT_COR_SRC = Macro("PCI_ERR_ROOT_COR_SRC", 52)
#: Constant from pci.h
PCI_ERR_ROOT_SRC = Macro("PCI_ERR_ROOT_SRC", 54)
#: Constant from pci.h
PCI_VC_PORT_REG1 = Macro("PCI_VC_PORT_REG1", 4)
#: Constant from pci.h
PCI_VC_PORT_REG2 = Macro("PCI_VC_PORT_REG2", 8)
#: Constant from pci.h
PCI_VC_PORT_CTRL = Macro("PCI_VC_PORT_CTRL", 12)
#: Constant from pci.h
PCI_VC_PORT_STATUS = Macro("PCI_VC_PORT_STATUS", 14)
#: Constant from pci.h
PCI_VC_RES_CAP = Macro("PCI_VC_RES_CAP", 16)
#: Constant from pci.h
PCI_VC_RES_CTRL = Macro("PCI_VC_RES_CTRL", 20)
#: Constant from pci.h
PCI_VC_RES_STATUS = Macro("PCI_VC_RES_STATUS", 26)
#: Constant from pci.h
PCI_PWR_DSR = Macro("PCI_PWR_DSR", 4)
#: Constant from pci.h
PCI_PWR_DATA = Macro("PCI_PWR_DATA", 8)
# define  PCI_PWR_DATA_BASE(x)	((x) & 0xff)
# define  PCI_PWR_DATA_SCALE(x)	(((x) >> 8) & 3)
# define  PCI_PWR_DATA_PM_SUB(x)	(((x) >> 10) & 7)
# define  PCI_PWR_DATA_PM_STATE(x) (((x) >> 13) & 3)
# define  PCI_PWR_DATA_TYPE(x)	(((x) >> 15) & 7)
# define  PCI_PWR_DATA_RAIL(x)	(((x) >> 18) & 7)
#: Constant from pci.h
PCI_PWR_CAP = Macro("PCI_PWR_CAP", 12)
# define  PCI_PWR_CAP_BUDGET(x)	((x) & 1)
#: Constant from pci.h
PCI_RCLINK_ESD = Macro("PCI_RCLINK_ESD", 4)
#: Constant from pci.h
PCI_RCLINK_LINK1 = Macro("PCI_RCLINK_LINK1", 16)
#: Constant from pci.h
PCI_RCLINK_LINK_DESC = Macro("PCI_RCLINK_LINK_DESC", 0)
#: Constant from pci.h
PCI_RCLINK_LINK_ADDR = Macro("PCI_RCLINK_LINK_ADDR", 8)
#: Constant from pci.h
PCI_RCLINK_LINK_SIZE = Macro("PCI_RCLINK_LINK_SIZE", 16)
#: Constant from pci.h
PCI_EVNDR_HEADER = Macro("PCI_EVNDR_HEADER", 4)
#: Constant from pci.h
PCI_EVNDR_REGISTERS = Macro("PCI_EVNDR_REGISTERS", 8)
#: Constant from pci.h
PCI_ACS_CAP = Macro("PCI_ACS_CAP", 0x04)
#: Constant from pci.h
PCI_ACS_CAP_VALID = Macro("PCI_ACS_CAP_VALID", 0x0001)
#: Constant from pci.h
PCI_ACS_CAP_BLOCK = Macro("PCI_ACS_CAP_BLOCK", 0x0002)
#: Constant from pci.h
PCI_ACS_CAP_REQ_RED = Macro("PCI_ACS_CAP_REQ_RED", 0x0004)
#: Constant from pci.h
PCI_ACS_CAP_CMPLT_RED = Macro("PCI_ACS_CAP_CMPLT_RED", 0x0008)
#: Constant from pci.h
PCI_ACS_CAP_FORWARD = Macro("PCI_ACS_CAP_FORWARD", 0x0010)
#: Constant from pci.h
PCI_ACS_CAP_EGRESS = Macro("PCI_ACS_CAP_EGRESS", 0x0020)
#: Constant from pci.h
PCI_ACS_CAP_TRANS = Macro("PCI_ACS_CAP_TRANS", 0x0040)
# define PCI_ACS_CAP_VECTOR(x)	(((x) >> 8) & 0xff)
#: Constant from pci.h
PCI_ACS_CTRL = Macro("PCI_ACS_CTRL", 0x06)
#: Constant from pci.h
PCI_ACS_CTRL_VALID = Macro("PCI_ACS_CTRL_VALID", 0x0001)
#: Constant from pci.h
PCI_ACS_CTRL_BLOCK = Macro("PCI_ACS_CTRL_BLOCK", 0x0002)
#: Constant from pci.h
PCI_ACS_CTRL_REQ_RED = Macro("PCI_ACS_CTRL_REQ_RED", 0x0004)
#: Constant from pci.h
PCI_ACS_CTRL_CMPLT_RED = Macro("PCI_ACS_CTRL_CMPLT_RED", 0x0008)
#: Constant from pci.h
PCI_ACS_CTRL_FORWARD = Macro("PCI_ACS_CTRL_FORWARD", 0x0010)
#: Constant from pci.h
PCI_ACS_CTRL_EGRESS = Macro("PCI_ACS_CTRL_EGRESS", 0x0020)
#: Constant from pci.h
PCI_ACS_CTRL_TRANS = Macro("PCI_ACS_CTRL_TRANS", 0x0040)
#: Constant from pci.h
PCI_ACS_EGRESS_CTRL = Macro("PCI_ACS_EGRESS_CTRL", 0x08)
#: Constant from pci.h
PCI_ARI_CAP = Macro("PCI_ARI_CAP", 0x04)
#: Constant from pci.h
PCI_ARI_CAP_MFVC = Macro("PCI_ARI_CAP_MFVC", 0x0001)
#: Constant from pci.h
PCI_ARI_CAP_ACS = Macro("PCI_ARI_CAP_ACS", 0x0002)
# define  PCI_ARI_CAP_NFN(x)	(((x) >> 8) & 0xff)
#: Constant from pci.h
PCI_ARI_CTRL = Macro("PCI_ARI_CTRL", 0x06)
#: Constant from pci.h
PCI_ARI_CTRL_MFVC = Macro("PCI_ARI_CTRL_MFVC", 0x0001)
#: Constant from pci.h
PCI_ARI_CTRL_ACS = Macro("PCI_ARI_CTRL_ACS", 0x0002)
# define  PCI_ARI_CTRL_FG(x)	(((x) >> 4) & 7)
#: Constant from pci.h
PCI_ATS_CAP = Macro("PCI_ATS_CAP", 0x04)
# define  PCI_ATS_CAP_IQD(x)	((x) & 0x1f)
#: Constant from pci.h
PCI_ATS_CTRL = Macro("PCI_ATS_CTRL", 0x06)
# define  PCI_ATS_CTRL_STU(x)	((x) & 0x1f)
#: Constant from pci.h
PCI_ATS_CTRL_ENABLE = Macro("PCI_ATS_CTRL_ENABLE", 0x8000)
#: Constant from pci.h
PCI_IOV_CAP = Macro("PCI_IOV_CAP", 0x04)
#: Constant from pci.h
PCI_IOV_CAP_VFM = Macro("PCI_IOV_CAP_VFM", 0x00000001)
# define  PCI_IOV_CAP_IMN(x)	((x) >> 21)
#: Constant from pci.h
PCI_IOV_CTRL = Macro("PCI_IOV_CTRL", 0x08)
#: Constant from pci.h
PCI_IOV_CTRL_VFE = Macro("PCI_IOV_CTRL_VFE", 0x0001)
#: Constant from pci.h
PCI_IOV_CTRL_VFME = Macro("PCI_IOV_CTRL_VFME", 0x0002)
#: Constant from pci.h
PCI_IOV_CTRL_VFMIE = Macro("PCI_IOV_CTRL_VFMIE", 0x0004)
#: Constant from pci.h
PCI_IOV_CTRL_MSE = Macro("PCI_IOV_CTRL_MSE", 0x0008)
#: Constant from pci.h
PCI_IOV_CTRL_ARI = Macro("PCI_IOV_CTRL_ARI", 0x0010)
#: Constant from pci.h
PCI_IOV_STATUS = Macro("PCI_IOV_STATUS", 0x0a)
#: Constant from pci.h
PCI_IOV_STATUS_MS = Macro("PCI_IOV_STATUS_MS", 0x0001)
#: Constant from pci.h
PCI_IOV_INITIALVF = Macro("PCI_IOV_INITIALVF", 0x0c)
#: Constant from pci.h
PCI_IOV_TOTALVF = Macro("PCI_IOV_TOTALVF", 0x0e)
#: Constant from pci.h
PCI_IOV_NUMVF = Macro("PCI_IOV_NUMVF", 0x10)
#: Constant from pci.h
PCI_IOV_FDL = Macro("PCI_IOV_FDL", 0x12)
#: Constant from pci.h
PCI_IOV_OFFSET = Macro("PCI_IOV_OFFSET", 0x14)
#: Constant from pci.h
PCI_IOV_STRIDE = Macro("PCI_IOV_STRIDE", 0x16)
#: Constant from pci.h
PCI_IOV_DID = Macro("PCI_IOV_DID", 0x1a)
#: Constant from pci.h
PCI_IOV_SUPPS = Macro("PCI_IOV_SUPPS", 0x1c)
#: Constant from pci.h
PCI_IOV_SYSPS = Macro("PCI_IOV_SYSPS", 0x20)
#: Constant from pci.h
PCI_IOV_BAR_BASE = Macro("PCI_IOV_BAR_BASE", 0x24)
#: Constant from pci.h
PCI_IOV_NUM_BAR = Macro("PCI_IOV_NUM_BAR", 6)
#: Constant from pci.h
PCI_IOV_MSAO = Macro("PCI_IOV_MSAO", 0x3c)
# define PCI_IOV_MSA_BIR(x)	((x) & 7)
# define PCI_IOV_MSA_OFFSET(x)	((x) & 0xfffffff8)
#: Constant from pci.h
PCI_TPH_CAPABILITIES = Macro("PCI_TPH_CAPABILITIES", 4)
# define   PCI_TPH_INTVEC_SUP	(1<<1)
# define   PCI_TPH_DEV_SUP      	(1<<2)
# define   PCI_TPH_EXT_REQ_SUP	(1<<8)
# define   PCI_TPH_ST_LOC_MASK	(3<<9)
# define     PCI_TPH_ST_NONE	(0<<9)
# define     PCI_TPH_ST_CAP	(1<<9)
# define     PCI_TPH_ST_MSIX	(2<<9)
# define   PCI_TPH_ST_SIZE_SHIFT	(16)
#: Constant from pci.h
PCI_LTR_MAX_SNOOP = Macro("PCI_LTR_MAX_SNOOP", 4)
# define   PCI_LTR_VALUE_MASK	(0x3ff)
# define   PCI_LTR_SCALE_SHIFT	(10)
# define   PCI_LTR_SCALE_MASK	(7)
#: Constant from pci.h
PCI_LTR_MAX_NOSNOOP = Macro("PCI_LTR_MAX_NOSNOOP", 6)
# define PCI_DEVFN(slot,func)	((((slot) & 0x1f) << 3) | ((func) & 0x07))
# define PCI_SLOT(devfn)		(((devfn) >> 3) & 0x1f)
# define PCI_FUNC(devfn)		((devfn) & 0x07)
#: Constant from pci.h
PCI_CLASS_NOT_DEFINED = Macro("PCI_CLASS_NOT_DEFINED", 0x0000)
#: Constant from pci.h
PCI_CLASS_NOT_DEFINED_VGA = Macro("PCI_CLASS_NOT_DEFINED_VGA", 0x0001)
#: Constant from pci.h
PCI_BASE_CLASS_STORAGE = Macro("PCI_BASE_CLASS_STORAGE", 0x01)
#: Constant from pci.h
PCI_CLASS_STORAGE_SCSI = Macro("PCI_CLASS_STORAGE_SCSI", 0x0100)
#: Constant from pci.h
PCI_CLASS_STORAGE_IDE = Macro("PCI_CLASS_STORAGE_IDE", 0x0101)
#: Constant from pci.h
PCI_CLASS_STORAGE_FLOPPY = Macro("PCI_CLASS_STORAGE_FLOPPY", 0x0102)
#: Constant from pci.h
PCI_CLASS_STORAGE_IPI = Macro("PCI_CLASS_STORAGE_IPI", 0x0103)
#: Constant from pci.h
PCI_CLASS_STORAGE_RAID = Macro("PCI_CLASS_STORAGE_RAID", 0x0104)
#: Constant from pci.h
PCI_CLASS_STORAGE_ATA = Macro("PCI_CLASS_STORAGE_ATA", 0x0105)
#: Constant from pci.h
PCI_CLASS_STORAGE_SATA = Macro("PCI_CLASS_STORAGE_SATA", 0x0106)
#: Constant from pci.h
PCI_CLASS_STORAGE_SAS = Macro("PCI_CLASS_STORAGE_SAS", 0x0107)
#: Constant from pci.h
PCI_CLASS_STORAGE_OTHER = Macro("PCI_CLASS_STORAGE_OTHER", 0x0180)
#: Constant from pci.h
PCI_BASE_CLASS_NETWORK = Macro("PCI_BASE_CLASS_NETWORK", 0x02)
#: Constant from pci.h
PCI_CLASS_NETWORK_ETHERNET = Macro("PCI_CLASS_NETWORK_ETHERNET", 0x0200)
#: Constant from pci.h
PCI_CLASS_NETWORK_TOKEN_RING = Macro("PCI_CLASS_NETWORK_TOKEN_RING", 0x0201)
#: Constant from pci.h
PCI_CLASS_NETWORK_FDDI = Macro("PCI_CLASS_NETWORK_FDDI", 0x0202)
#: Constant from pci.h
PCI_CLASS_NETWORK_ATM = Macro("PCI_CLASS_NETWORK_ATM", 0x0203)
#: Constant from pci.h
PCI_CLASS_NETWORK_ISDN = Macro("PCI_CLASS_NETWORK_ISDN", 0x0204)
#: Constant from pci.h
PCI_CLASS_NETWORK_OTHER = Macro("PCI_CLASS_NETWORK_OTHER", 0x0280)
#: Constant from pci.h
PCI_BASE_CLASS_DISPLAY = Macro("PCI_BASE_CLASS_DISPLAY", 0x03)
#: Constant from pci.h
PCI_CLASS_DISPLAY_VGA = Macro("PCI_CLASS_DISPLAY_VGA", 0x0300)
#: Constant from pci.h
PCI_CLASS_DISPLAY_XGA = Macro("PCI_CLASS_DISPLAY_XGA", 0x0301)
#: Constant from pci.h
PCI_CLASS_DISPLAY_3D = Macro("PCI_CLASS_DISPLAY_3D", 0x0302)
#: Constant from pci.h
PCI_CLASS_DISPLAY_OTHER = Macro("PCI_CLASS_DISPLAY_OTHER", 0x0380)
#: Constant from pci.h
PCI_BASE_CLASS_MULTIMEDIA = Macro("PCI_BASE_CLASS_MULTIMEDIA", 0x04)
#: Constant from pci.h
PCI_CLASS_MULTIMEDIA_VIDEO = Macro("PCI_CLASS_MULTIMEDIA_VIDEO", 0x0400)
#: Constant from pci.h
PCI_CLASS_MULTIMEDIA_AUDIO = Macro("PCI_CLASS_MULTIMEDIA_AUDIO", 0x0401)
#: Constant from pci.h
PCI_CLASS_MULTIMEDIA_PHONE = Macro("PCI_CLASS_MULTIMEDIA_PHONE", 0x0402)
#: Constant from pci.h
PCI_CLASS_MULTIMEDIA_AUDIO_DEV = Macro(
    "PCI_CLASS_MULTIMEDIA_AUDIO_DEV", 0x0403)
#: Constant from pci.h
PCI_CLASS_MULTIMEDIA_OTHER = Macro("PCI_CLASS_MULTIMEDIA_OTHER", 0x0480)
#: Constant from pci.h
PCI_BASE_CLASS_MEMORY = Macro("PCI_BASE_CLASS_MEMORY", 0x05)
#: Constant from pci.h
PCI_CLASS_MEMORY_RAM = Macro("PCI_CLASS_MEMORY_RAM", 0x0500)
#: Constant from pci.h
PCI_CLASS_MEMORY_FLASH = Macro("PCI_CLASS_MEMORY_FLASH", 0x0501)
#: Constant from pci.h
PCI_CLASS_MEMORY_OTHER = Macro("PCI_CLASS_MEMORY_OTHER", 0x0580)
#: Constant from pci.h
PCI_BASE_CLASS_BRIDGE = Macro("PCI_BASE_CLASS_BRIDGE", 0x06)
#: Constant from pci.h
PCI_CLASS_BRIDGE_HOST = Macro("PCI_CLASS_BRIDGE_HOST", 0x0600)
#: Constant from pci.h
PCI_CLASS_BRIDGE_ISA = Macro("PCI_CLASS_BRIDGE_ISA", 0x0601)
#: Constant from pci.h
PCI_CLASS_BRIDGE_EISA = Macro("PCI_CLASS_BRIDGE_EISA", 0x0602)
#: Constant from pci.h
PCI_CLASS_BRIDGE_MC = Macro("PCI_CLASS_BRIDGE_MC", 0x0603)
#: Constant from pci.h
PCI_CLASS_BRIDGE_PCI = Macro("PCI_CLASS_BRIDGE_PCI", 0x0604)
#: Constant from pci.h
PCI_CLASS_BRIDGE_PCMCIA = Macro("PCI_CLASS_BRIDGE_PCMCIA", 0x0605)
#: Constant from pci.h
PCI_CLASS_BRIDGE_NUBUS = Macro("PCI_CLASS_BRIDGE_NUBUS", 0x0606)
#: Constant from pci.h
PCI_CLASS_BRIDGE_CARDBUS = Macro("PCI_CLASS_BRIDGE_CARDBUS", 0x0607)
#: Constant from pci.h
PCI_CLASS_BRIDGE_RACEWAY = Macro("PCI_CLASS_BRIDGE_RACEWAY", 0x0608)
#: Constant from pci.h
PCI_CLASS_BRIDGE_PCI_SEMI = Macro("PCI_CLASS_BRIDGE_PCI_SEMI", 0x0609)
#: Constant from pci.h
PCI_CLASS_BRIDGE_IB_TO_PCI = Macro("PCI_CLASS_BRIDGE_IB_TO_PCI", 0x060a)
#: Constant from pci.h
PCI_CLASS_BRIDGE_OTHER = Macro("PCI_CLASS_BRIDGE_OTHER", 0x0680)
#: Constant from pci.h
PCI_BASE_CLASS_COMMUNICATION = Macro("PCI_BASE_CLASS_COMMUNICATION", 0x07)
#: Constant from pci.h
PCI_CLASS_COMMUNICATION_SERIAL = Macro(
    "PCI_CLASS_COMMUNICATION_SERIAL", 0x0700)
#: Constant from pci.h
PCI_CLASS_COMMUNICATION_PARALLEL = Macro(
    "PCI_CLASS_COMMUNICATION_PARALLEL", 0x0701)
#: Constant from pci.h
PCI_CLASS_COMMUNICATION_MSERIAL = Macro(
    "PCI_CLASS_COMMUNICATION_MSERIAL", 0x0702)
#: Constant from pci.h
PCI_CLASS_COMMUNICATION_MODEM = Macro("PCI_CLASS_COMMUNICATION_MODEM", 0x0703)
#: Constant from pci.h
PCI_CLASS_COMMUNICATION_OTHER = Macro("PCI_CLASS_COMMUNICATION_OTHER", 0x0780)
#: Constant from pci.h
PCI_BASE_CLASS_SYSTEM = Macro("PCI_BASE_CLASS_SYSTEM", 0x08)
#: Constant from pci.h
PCI_CLASS_SYSTEM_PIC = Macro("PCI_CLASS_SYSTEM_PIC", 0x0800)
#: Constant from pci.h
PCI_CLASS_SYSTEM_DMA = Macro("PCI_CLASS_SYSTEM_DMA", 0x0801)
#: Constant from pci.h
PCI_CLASS_SYSTEM_TIMER = Macro("PCI_CLASS_SYSTEM_TIMER", 0x0802)
#: Constant from pci.h
PCI_CLASS_SYSTEM_RTC = Macro("PCI_CLASS_SYSTEM_RTC", 0x0803)
#: Constant from pci.h
PCI_CLASS_SYSTEM_PCI_HOTPLUG = Macro("PCI_CLASS_SYSTEM_PCI_HOTPLUG", 0x0804)
#: Constant from pci.h
PCI_CLASS_SYSTEM_OTHER = Macro("PCI_CLASS_SYSTEM_OTHER", 0x0880)
#: Constant from pci.h
PCI_BASE_CLASS_INPUT = Macro("PCI_BASE_CLASS_INPUT", 0x09)
#: Constant from pci.h
PCI_CLASS_INPUT_KEYBOARD = Macro("PCI_CLASS_INPUT_KEYBOARD", 0x0900)
#: Constant from pci.h
PCI_CLASS_INPUT_PEN = Macro("PCI_CLASS_INPUT_PEN", 0x0901)
#: Constant from pci.h
PCI_CLASS_INPUT_MOUSE = Macro("PCI_CLASS_INPUT_MOUSE", 0x0902)
#: Constant from pci.h
PCI_CLASS_INPUT_SCANNER = Macro("PCI_CLASS_INPUT_SCANNER", 0x0903)
#: Constant from pci.h
PCI_CLASS_INPUT_GAMEPORT = Macro("PCI_CLASS_INPUT_GAMEPORT", 0x0904)
#: Constant from pci.h
PCI_CLASS_INPUT_OTHER = Macro("PCI_CLASS_INPUT_OTHER", 0x0980)
#: Constant from pci.h
PCI_BASE_CLASS_DOCKING = Macro("PCI_BASE_CLASS_DOCKING", 0x0a)
#: Constant from pci.h
PCI_CLASS_DOCKING_GENERIC = Macro("PCI_CLASS_DOCKING_GENERIC", 0x0a00)
#: Constant from pci.h
PCI_CLASS_DOCKING_OTHER = Macro("PCI_CLASS_DOCKING_OTHER", 0x0a80)
#: Constant from pci.h
PCI_BASE_CLASS_PROCESSOR = Macro("PCI_BASE_CLASS_PROCESSOR", 0x0b)
#: Constant from pci.h
PCI_CLASS_PROCESSOR_386 = Macro("PCI_CLASS_PROCESSOR_386", 0x0b00)
#: Constant from pci.h
PCI_CLASS_PROCESSOR_486 = Macro("PCI_CLASS_PROCESSOR_486", 0x0b01)
#: Constant from pci.h
PCI_CLASS_PROCESSOR_PENTIUM = Macro("PCI_CLASS_PROCESSOR_PENTIUM", 0x0b02)
#: Constant from pci.h
PCI_CLASS_PROCESSOR_ALPHA = Macro("PCI_CLASS_PROCESSOR_ALPHA", 0x0b10)
#: Constant from pci.h
PCI_CLASS_PROCESSOR_POWERPC = Macro("PCI_CLASS_PROCESSOR_POWERPC", 0x0b20)
#: Constant from pci.h
PCI_CLASS_PROCESSOR_MIPS = Macro("PCI_CLASS_PROCESSOR_MIPS", 0x0b30)
#: Constant from pci.h
PCI_CLASS_PROCESSOR_CO = Macro("PCI_CLASS_PROCESSOR_CO", 0x0b40)
#: Constant from pci.h
PCI_BASE_CLASS_SERIAL = Macro("PCI_BASE_CLASS_SERIAL", 0x0c)
#: Constant from pci.h
PCI_CLASS_SERIAL_FIREWIRE = Macro("PCI_CLASS_SERIAL_FIREWIRE", 0x0c00)
#: Constant from pci.h
PCI_CLASS_SERIAL_ACCESS = Macro("PCI_CLASS_SERIAL_ACCESS", 0x0c01)
#: Constant from pci.h
PCI_CLASS_SERIAL_SSA = Macro("PCI_CLASS_SERIAL_SSA", 0x0c02)
#: Constant from pci.h
PCI_CLASS_SERIAL_USB = Macro("PCI_CLASS_SERIAL_USB", 0x0c03)
#: Constant from pci.h
PCI_CLASS_SERIAL_FIBER = Macro("PCI_CLASS_SERIAL_FIBER", 0x0c04)
#: Constant from pci.h
PCI_CLASS_SERIAL_SMBUS = Macro("PCI_CLASS_SERIAL_SMBUS", 0x0c05)
#: Constant from pci.h
PCI_CLASS_SERIAL_INFINIBAND = Macro("PCI_CLASS_SERIAL_INFINIBAND", 0x0c06)
#: Constant from pci.h
PCI_BASE_CLASS_WIRELESS = Macro("PCI_BASE_CLASS_WIRELESS", 0x0d)
#: Constant from pci.h
PCI_CLASS_WIRELESS_IRDA = Macro("PCI_CLASS_WIRELESS_IRDA", 0x0d00)
#: Constant from pci.h
PCI_CLASS_WIRELESS_CONSUMER_IR = Macro(
    "PCI_CLASS_WIRELESS_CONSUMER_IR", 0x0d01)
#: Constant from pci.h
PCI_CLASS_WIRELESS_RF = Macro("PCI_CLASS_WIRELESS_RF", 0x0d10)
#: Constant from pci.h
PCI_CLASS_WIRELESS_OTHER = Macro("PCI_CLASS_WIRELESS_OTHER", 0x0d80)
#: Constant from pci.h
PCI_BASE_CLASS_INTELLIGENT = Macro("PCI_BASE_CLASS_INTELLIGENT", 0x0e)
#: Constant from pci.h
PCI_CLASS_INTELLIGENT_I2O = Macro("PCI_CLASS_INTELLIGENT_I2O", 0x0e00)
#: Constant from pci.h
PCI_BASE_CLASS_SATELLITE = Macro("PCI_BASE_CLASS_SATELLITE", 0x0f)
#: Constant from pci.h
PCI_CLASS_SATELLITE_TV = Macro("PCI_CLASS_SATELLITE_TV", 0x0f00)
#: Constant from pci.h
PCI_CLASS_SATELLITE_AUDIO = Macro("PCI_CLASS_SATELLITE_AUDIO", 0x0f01)
#: Constant from pci.h
PCI_CLASS_SATELLITE_VOICE = Macro("PCI_CLASS_SATELLITE_VOICE", 0x0f03)
#: Constant from pci.h
PCI_CLASS_SATELLITE_DATA = Macro("PCI_CLASS_SATELLITE_DATA", 0x0f04)
#: Constant from pci.h
PCI_BASE_CLASS_CRYPT = Macro("PCI_BASE_CLASS_CRYPT", 0x10)
#: Constant from pci.h
PCI_CLASS_CRYPT_NETWORK = Macro("PCI_CLASS_CRYPT_NETWORK", 0x1000)
#: Constant from pci.h
PCI_CLASS_CRYPT_ENTERTAINMENT = Macro("PCI_CLASS_CRYPT_ENTERTAINMENT", 0x1010)
#: Constant from pci.h
PCI_CLASS_CRYPT_OTHER = Macro("PCI_CLASS_CRYPT_OTHER", 0x1080)
#: Constant from pci.h
PCI_BASE_CLASS_SIGNAL = Macro("PCI_BASE_CLASS_SIGNAL", 0x11)
#: Constant from pci.h
PCI_CLASS_SIGNAL_DPIO = Macro("PCI_CLASS_SIGNAL_DPIO", 0x1100)
#: Constant from pci.h
PCI_CLASS_SIGNAL_PERF_CTR = Macro("PCI_CLASS_SIGNAL_PERF_CTR", 0x1101)
#: Constant from pci.h
PCI_CLASS_SIGNAL_SYNCHRONIZER = Macro("PCI_CLASS_SIGNAL_SYNCHRONIZER", 0x1110)
#: Constant from pci.h
PCI_CLASS_SIGNAL_OTHER = Macro("PCI_CLASS_SIGNAL_OTHER", 0x1180)
#: Constant from pci.h
PCI_CLASS_OTHERS = Macro("PCI_CLASS_OTHERS", 0xff)
#: Constant from pci.h
PCI_VENDOR_ID_INTEL = Macro("PCI_VENDOR_ID_INTEL", 0x8086)
#: Constant from pci.h
PCI_VENDOR_ID_COMPAQ = Macro("PCI_VENDOR_ID_COMPAQ", 0x0e11)


# Automatically-generated __all__
__all__ = tuple(name for name in locals().keys() if name.startswith('PCI'))
